@@ -45,16 +45,10 @@ class Imager : public virtual INDI::DefaultDevice, public virtual INDI::BaseClie
 
         // BaseClient
 
-        virtual void newDevice(INDI::BaseDevice *dp) override;
-        virtual void newProperty(INDI::Property *property) override;
-        virtual void removeProperty(INDI::Property *property) override;
-        virtual void removeDevice(INDI::BaseDevice *dp) override;
-        virtual void newBLOB(IBLOB *bp) override;
-        virtual void newSwitch(ISwitchVectorProperty *svp) override;
-        virtual void newNumber(INumberVectorProperty *nvp) override;
-        virtual void newText(ITextVectorProperty *tvp) override;
-        virtual void newLight(ILightVectorProperty *lvp) override;
-        virtual void newMessage(INDI::BaseDevice *dp, int messageID) override;
+        virtual void newDevice(INDI::BaseDevice baseDevice) override;
+        virtual void newProperty(INDI::Property property) override;
+        virtual void updateProperty(INDI::Property property) override;
+
         virtual void serverConnected() override;
         virtual void serverDisconnected(int exit_code) override;
 
