@@ -34,12 +34,12 @@ class DeltaT : public INDI::DefaultDevice
         DeltaT();
 
         virtual bool Handshake();
-        const char *getDefaultName();
-        virtual bool initProperties();
-        virtual bool updateProperties();
+        const char *getDefaultName() override;
+        virtual bool initProperties() override;
+        virtual bool updateProperties() override;
 
-        virtual bool ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n);
-        virtual bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n);
+        virtual bool ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n) override;
+        virtual bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n) override;
 
         enum
         {
@@ -78,8 +78,8 @@ class DeltaT : public INDI::DefaultDevice
 
 
     protected:
-        virtual void TimerHit();
-        virtual bool saveConfigItems(FILE *fp);
+        virtual void TimerHit() override;
+        virtual bool saveConfigItems(FILE *fp) override;
 
     private:
         ///////////////////////////////////////////////////////////////////////////////////
