@@ -40,43 +40,6 @@ static std::unique_ptr<SQM> sqm(new SQM());
 
 #define UNIT_TAB    "Unit"
 
-void ISGetProperties(const char *dev)
-{
-    sqm->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    sqm->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    sqm->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    sqm->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-void ISSnoopDevice(XMLEle *root)
-{
-    sqm->ISSnoopDevice(root);
-}
-
 SQM::SQM()
 {
     setVersion(1, 3);
@@ -138,8 +101,8 @@ bool SQM::updateProperties()
 
     if (isConnected())
     {
-        defineNumber(&AverageReadingNP);
-        defineNumber(&UnitInfoNP);
+        defineProperty(&AverageReadingNP);
+        defineProperty(&UnitInfoNP);
 
         getReadings();
 
@@ -260,7 +223,7 @@ void SQM::TimerHit()
     AverageReadingNP.s = rc ? IPS_OK : IPS_ALERT;
     IDSetNumber(&AverageReadingNP, nullptr);
 
-    SetTimer(POLLMS);
+    SetTimer(getCurrentPollingPeriod());
 }
 
 /////////////////////////////////////////////////////////////////////////////
