@@ -41,46 +41,6 @@ std::unique_ptr<BaaderDome> baaderDome(new BaaderDome());
 #define SIM_DOME_HI_SPEED 5.0 /* Simulated dome speed 5.0 degrees per second, constant */
 #define SIM_DOME_LO_SPEED 0.5 /* Simulated dome speed 0.5 degrees per second, constant */
 
-void ISPoll(void *p);
-
-void ISGetProperties(const char *dev)
-{
-    baaderDome->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    baaderDome->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    baaderDome->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    baaderDome->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-
-void ISSnoopDevice(XMLEle *root)
-{
-    baaderDome->ISSnoopDevice(root);
-}
-
 BaaderDome::BaaderDome()
 {
     targetAz         = 0;
@@ -174,8 +134,8 @@ bool BaaderDome::updateProperties()
 
     if (isConnected())
     {
-        defineSwitch(&DomeFlapSP);
-        defineSwitch(&CalibrateSP);
+        defineProperty(&DomeFlapSP);
+        defineProperty(&CalibrateSP);
 
         SetupParms();
     }
@@ -658,7 +618,7 @@ void BaaderDome::TimerHit()
     else
         IDSetSwitch(&DomeFlapSP, nullptr);
 
-    SetTimer(POLLMS);
+    SetTimer(getCurrentPollingPeriod());
 }
 
 /************************************************************************************
