@@ -32,44 +32,6 @@
 
 static std::unique_ptr<DomePro2> domepro2(new DomePro2());
 
-void ISGetProperties(const char *dev)
-{
-    domepro2->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    domepro2->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    domepro2->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    domepro2->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-
-void ISSnoopDevice(XMLEle *root)
-{
-    domepro2->ISSnoopDevice(root);
-}
-
 DomePro2::DomePro2()
 {
     m_ShutterState     = SHUTTER_UNKNOWN;
@@ -176,10 +138,10 @@ bool DomePro2::updateProperties()
     {
         setupInitialParameters();
 
-        defineText(&VersionTP);
-        defineText(&StatusTP);
-        defineNumber(&SettingsNP);
-        defineSwitch(&HomeSP);
+        defineProperty(&VersionTP);
+        defineProperty(&StatusTP);
+        defineProperty(&SettingsNP);
+        defineProperty(&HomeSP);
     }
     else
     {
@@ -375,7 +337,7 @@ void DomePro2::TimerHit()
         IDSetText(&StatusTP, nullptr);
     }
 
-    SetTimer(POLLMS);
+    SetTimer(getCurrentPollingPeriod());
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////
