@@ -34,43 +34,6 @@ const uint8_t COMM_FILL = 0x20;
 
 static std::unique_ptr<TruTech> tru_wheel(new TruTech());
 
-void ISGetProperties(const char *dev)
-{
-    tru_wheel->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    tru_wheel->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    tru_wheel->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    tru_wheel->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-void ISSnoopDevice(XMLEle *root)
-{
-    tru_wheel->ISSnoopDevice(root);
-}
-
 TruTech::TruTech()
 {
     setVersion(1, 0);
@@ -100,7 +63,7 @@ bool TruTech::updateProperties()
     INDI::FilterWheel::updateProperties();
 
     if (isConnected())
-        defineSwitch(&HomeSP);
+        defineProperty(&HomeSP);
     else
         deleteProperty(HomeSP.name);
 
@@ -248,5 +211,5 @@ void TruTech::TimerHit()
         }
     }
 
-    SetTimer(POLLMS);
+    SetTimer(getCurrentPollingPeriod());
 }
