@@ -31,46 +31,6 @@
 
 static std::unique_ptr<HitecAstroDCFocuser> hitecastroDcFocuser(new HitecAstroDCFocuser());
 
-void ISPoll(void *p);
-
-void ISGetProperties(const char *dev)
-{
-    hitecastroDcFocuser->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    hitecastroDcFocuser->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    hitecastroDcFocuser->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    hitecastroDcFocuser->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-
-void ISSnoopDevice(XMLEle *root)
-{
-    hitecastroDcFocuser->ISSnoopDevice(root);
-}
-
 HitecAstroDCFocuser::HitecAstroDCFocuser() : m_HIDHandle(nullptr)
 {
     FI::SetCapability(FOCUSER_CAN_REL_MOVE | FOCUSER_CAN_REVERSE);
@@ -104,7 +64,7 @@ bool HitecAstroDCFocuser::Connect()
     if (m_HIDHandle != nullptr)
     {
         LOG_INFO("Experimental driver. Report issues to https://github.com/A-j-K/hitecastrodcfocuser/issues");
-        SetTimer(POLLMS);
+        SetTimer(getCurrentPollingPeriod());
         return true;
     }
 
@@ -171,9 +131,9 @@ bool HitecAstroDCFocuser::updateProperties()
 
     if (isConnected())
     {
-        //defineNumber(&MaxPositionNP);
-        defineNumber(&SlewSpeedNP);
-        //defineSwitch(&ReverseDirectionSP);
+        //defineProperty(&MaxPositionNP);
+        defineProperty(&SlewSpeedNP);
+        //defineProperty(&ReverseDirectionSP);
     }
     else
     {
