@@ -36,62 +36,6 @@
 static std::unique_ptr<MoonLiteDRO> dro1(new MoonLiteDRO(1));
 static std::unique_ptr<MoonLiteDRO> dro2(new MoonLiteDRO(2));
 
-void ISGetProperties(const char *dev)
-{
-    if (dev == nullptr)
-    {
-        dro1->ISGetProperties(dev);
-        dro2->ISGetProperties(dev);
-    }
-    else if (!strcmp(dev, dro1->getDeviceName()))
-        dro1->ISGetProperties(dev);
-    else if (!strcmp(dev, dro2->getDeviceName()))
-        dro2->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    if (!strcmp(dev, dro1->getDeviceName()))
-        dro1->ISNewSwitch(dev, name, states, names, n);
-    else if (!strcmp(dev, dro2->getDeviceName()))
-        dro2->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    if (!strcmp(dev, dro1->getDeviceName()))
-        dro1->ISNewText(dev, name, texts, names, n);
-    else if (!strcmp(dev, dro2->getDeviceName()))
-        dro2->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    if (!strcmp(dev, dro1->getDeviceName()))
-        dro1->ISNewNumber(dev, name, values, names, n);
-    else if (!strcmp(dev, dro2->getDeviceName()))
-        dro2->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-
-void ISSnoopDevice(XMLEle *root)
-{
-    dro1->ISSnoopDevice(root);
-    dro2->ISSnoopDevice(root);
-}
-
 MoonLiteDRO::MoonLiteDRO(int ID) : m_ID(ID)
 {
     FI::SetCapability(FOCUSER_CAN_ABS_MOVE | FOCUSER_CAN_REL_MOVE | FOCUSER_CAN_ABORT | FOCUSER_CAN_SYNC);
@@ -165,13 +109,13 @@ bool MoonLiteDRO::updateProperties()
         // Only display such properties for the first focuser only
         if (m_ID == 1)
         {
-            defineNumber(&TemperatureNP);
-            defineNumber(&TemperatureSettingNP);
-            defineSwitch(&TemperatureCompensateSP);
+            defineProperty(&TemperatureNP);
+            defineProperty(&TemperatureSettingNP);
+            defineProperty(&TemperatureCompensateSP);
         }
 
-        defineNumber(&StepDelayNP);
-        defineSwitch(&StepModeSP);
+        defineProperty(&StepDelayNP);
+        defineProperty(&StepModeSP);
 
         GetFocusParams();
 
@@ -205,7 +149,7 @@ bool MoonLiteDRO::Connect()
     }
 
     PortFD = dro1->getPortFD();
-    SetTimer(POLLMS);
+    SetTimer(getCurrentPollingPeriod());
     return true;
 }
 
@@ -945,7 +889,7 @@ void MoonLiteDRO::TimerHit()
 {
     if (!isConnected())
     {
-        SetTimer(POLLMS);
+        SetTimer(getCurrentPollingPeriod());
         return;
     }
 
@@ -986,7 +930,7 @@ void MoonLiteDRO::TimerHit()
         }
     }
 
-    SetTimer(POLLMS);
+    SetTimer(getCurrentPollingPeriod());
 }
 
 bool MoonLiteDRO::AbortFocuser()
