@@ -30,44 +30,6 @@
 
 static std::unique_ptr<NStep> nstep(new NStep());
 
-void ISGetProperties(const char *dev)
-{
-    nstep->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    nstep->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    nstep->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    nstep->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-
-void ISSnoopDevice(XMLEle *root)
-{
-    nstep->ISSnoopDevice(root);
-}
-
 NStep::NStep()
 {
     setVersion(1, 2);
@@ -100,10 +62,14 @@ bool NStep::initProperties()
                        COMPENSATION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_OK);
 
     // Compensation Settings
-    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_CHANGE], "COMPENSATION_SETTING_CHANGE", "Delta T. (C)", "%.1f", -99, 99, 0.1, 0);
-    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_STEP], "COMPENSATION_SETTING_STEP", "Steps per Delta", "%.0f", 0, 999, 1, 0);
-    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_BACKLASH], "COMPENSATION_SETTING_BACKLASH", "Backlash steps", "%.0f", 0, 999, 1, 0);
-    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_TIMER], "COMPENSATION_SETTING_TIMER", "Averaged Time (s)", "%.0f", 0, 75, 1, 0);
+    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_CHANGE], "COMPENSATION_SETTING_CHANGE", "Delta T. (C)", "%.1f",
+                 -99, 99, 0.1, 0);
+    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_STEP], "COMPENSATION_SETTING_STEP", "Steps per Delta", "%.0f", 0,
+                 999, 1, 0);
+    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_BACKLASH], "COMPENSATION_SETTING_BACKLASH", "Backlash steps",
+                 "%.0f", 0, 999, 1, 0);
+    IUFillNumber(&CompensationSettingsN[COMPENSATION_SETTING_TIMER], "COMPENSATION_SETTING_TIMER", "Averaged Time (s)", "%.0f",
+                 0, 75, 1, 0);
     IUFillNumberVector(&CompensationSettingsNP, CompensationSettingsN, 4, getDeviceName(), "COMPENSATION_SETTING", "Settings",
                        COMPENSATION_TAB, IP_RW, 0, IPS_OK);
 
@@ -126,7 +92,7 @@ bool NStep::initProperties()
 
     // Coil Energized Status
     IUFillSwitch(&CoilStatusS[COIL_ENERGIZED_OFF], "COIL_ENERGIZED_OFF", "De-energized", ISS_OFF);
-    IUFillSwitch(&CoilStatusS[COIL_ENERGIZED_ON], "COIL_ENERGIZED_OFF", "Energized", ISS_OFF);
+    IUFillSwitch(&CoilStatusS[COIL_ENERGIZED_ON], "COIL_ENERGIZED_ON", "Energized", ISS_OFF);
     IUFillSwitchVector(&CoilStatusSP, CoilStatusS, 2, getDeviceName(), "COIL_MODE", "Coil After Move",
                        OPTIONS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_OK);
 
@@ -167,18 +133,18 @@ bool NStep::updateProperties()
     if (isConnected())
     {
         if (readTemperature())
-            defineNumber(&TemperatureNP);
+            defineProperty(&TemperatureNP);
 
         bool rc = getStartupValues();
 
         // Settings
-        defineNumber(&MaxSpeedNP);
-        defineSwitch(&CompensationModeSP);
-        defineSwitch(&PrimeManualSP);
-        defineNumber(&CompensationSettingsNP);
-        defineSwitch(&SteppingModeSP);
-        defineNumber(&SteppingPhaseNP);
-        defineSwitch(&CoilStatusSP);
+        defineProperty(&MaxSpeedNP);
+        defineProperty(&CompensationModeSP);
+        defineProperty(&PrimeManualSP);
+        defineProperty(&CompensationSettingsNP);
+        defineProperty(&SteppingModeSP);
+        defineProperty(&SteppingPhaseNP);
+        defineProperty(&CoilStatusSP);
 
         if (rc)
             LOG_INFO("NStep is ready.");
@@ -553,7 +519,7 @@ void NStep::TimerHit()
             IDSetNumber(&TemperatureNP, nullptr);
     }
 
-    SetTimer(POLLMS);
+    SetTimer(getCurrentPollingPeriod());
 }
 
 bool NStep::isMoving()
