@@ -21,7 +21,7 @@
 #pragma once
 
 #include "indifocuser.h"
-
+#include "inditimer.h"
 
 class CommandSet
 {
@@ -49,22 +49,32 @@ class CommandSet
         bool initCalibration();
         bool getAbsolutePosition(char *res);
         bool getCurrentSpeed(char *res);
-        bool loadSlowPreset(char *res);
+        bool applyMotorPreset(const char *name);
+        bool applyMotorUserPreset(uint32_t index);
+        bool saveMotorUserPreset(uint32_t index, struct MotorRates &mr, struct MotorCurrents &mc);
         bool getMotorTemp(char *res);
         bool getExternalTemp(char *res);
         bool getVoltageIn(char *res);
+        bool getMotorSettings(struct MotorRates &ms, struct MotorCurrents &mc, bool &motorHoldActive);
+        bool setMotorRates(struct MotorRates &ms);
+        bool setMotorCurrents(struct MotorCurrents &mc);
+        bool setMotorHold(bool hold);
         std::string deviceName;
 
-        const char *getDeviceName()
+        const char *getDeviceName() const
         {
-            return deviceName.data();
+            return deviceName.c_str();
         }
 
     private:
 
-        bool sendCmd(std::string cmd, std::string property = "", char * res = nullptr);
-        bool getValueFromResponse(std::string response, std::string property, char *value);
-        std::string removeChars(std::string response, char ch);
+        // Send request and return full response
+        bool send(const std::string &request, std::string &response) const;
+        // Send command and parse response looking for value of property
+        bool sendCmd(const std::string &cmd, std::string property = "", char *res = nullptr) const;
+        bool sendCmd(const std::string &cmd, std::string property, std::string &res) const;
+        bool getValueFromResponse(const std::string &response, const std::string &property, char *value) const;
+        bool parseUIntFromResponse(const std::string &response, const std::string &property, uint32_t &result) const;
 
         // Maximum buffer for sending/receving.
         static constexpr const int SESTO_LEN {1024};
@@ -86,9 +96,10 @@ class SestoSenso2 : public INDI::Focuser
         virtual bool initProperties() override;
         virtual bool updateProperties() override;
         virtual bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n) override;
+        virtual bool ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n) override;
 
-        static void checkMotionProgressHelper(void *context);
-        static void checkHallSensorHelper(void *context);
+        //        static void checkMotionProgressHelper(void *context);
+        //        static void checkHallSensorHelper(void *context);
 
     protected:
         virtual bool Handshake() override;
@@ -98,6 +109,9 @@ class SestoSenso2 : public INDI::Focuser
         virtual bool ReverseFocuser(bool enabled) override;
         virtual bool AbortFocuser() override;
         virtual void TimerHit() override;
+        virtual bool SetFocuserBacklash(int32_t steps) override;
+
+        virtual bool saveConfigItems(FILE *fp) override;
 
     private:
         bool Ack();
@@ -108,6 +122,9 @@ class SestoSenso2 : public INDI::Focuser
         bool updateTemperature();
         bool updatePosition();
         bool updateVoltageIn();
+        bool fetchMotorSettings();
+        bool applyMotorRates();
+        bool applyMotorCurrents();
         void setConnectionParams();
         bool initCommandSet();
         void checkMotionProgressCallback();
@@ -116,12 +133,16 @@ class SestoSenso2 : public INDI::Focuser
         CommandSet *command {nullptr};
 
         bool getStartupValues();
-        bool setupRunPreset();
         void hexDump(char * buf, const char * data, int size);
         bool isMotionComplete();
 
+        FocusDirection backlashDirection { FOCUS_INWARD };
+        FocusDirection oldbacklashDirection { FOCUS_INWARD };
+        int32_t startPos { 0 };
+        uint32_t backlashTicks { 0 };
         uint32_t targetPos { 0 };
         uint32_t lastPos { 0 };
+        int32_t previousPos { 0 };
         double lastVoltageIn { 0 };
         double lastTemperature { 0 };
         uint16_t m_TemperatureCounter { 0 };
@@ -130,8 +151,8 @@ class SestoSenso2 : public INDI::Focuser
         INumber TemperatureN[2];
         enum
         {
-            TEMPERATURE_MOTOR,
             TEMPERATURE_EXTERNAL,
+            TEMPERATURE_MOTOR,
         };
 
         INumber SpeedN[1];
@@ -171,6 +192,60 @@ class SestoSenso2 : public INDI::Focuser
             CMD_FALSE = false
         };
 
+        INumberVectorProperty MotorRateNP;
+        INumber MotorRateN[3];
+        enum
+        {
+            MOTOR_RATE_ACC,
+            MOTOR_RATE_RUN,
+            MOTOR_RATE_DEC
+        };
+
+        INumberVectorProperty MotorCurrentNP;
+        INumber MotorCurrentN[4];
+        enum
+        {
+            MOTOR_CURR_ACC,
+            MOTOR_CURR_RUN,
+            MOTOR_CURR_DEC,
+            MOTOR_CURR_HOLD
+        };
+
+        ISwitchVectorProperty MotorHoldSP;
+        ISwitch MotorHoldS[2];
+        enum
+        {
+            MOTOR_HOLD_ON,
+            MOTOR_HOLD_OFF
+        };
+
+        ISwitchVectorProperty MotorApplyPresetSP;
+        ISwitch MotorApplyPresetS[3];
+        enum
+        {
+            MOTOR_APPLY_LIGHT,
+            MOTOR_APPLY_MEDIUM,
+            MOTOR_APPLY_HEAVY,
+        };
+
+        ISwitchVectorProperty MotorApplyUserPresetSP;
+        ISwitch MotorApplyUserPresetS[3];
+        enum
+        {
+            MOTOR_APPLY_USER1,
+            MOTOR_APPLY_USER2,
+            MOTOR_APPLY_USER3
+        };
+
+        ISwitchVectorProperty MotorSaveUserPresetSP;
+        ISwitch MotorSaveUserPresetS[3];
+        enum
+        {
+            MOTOR_SAVE_USER1,
+            MOTOR_SAVE_USER2,
+            MOTOR_SAVE_USER3
+        };
+
         ISwitchVectorProperty HomeSP;
         ISwitch HomeS[1];
 
@@ -180,8 +255,23 @@ class SestoSenso2 : public INDI::Focuser
         typedef enum { Idle, GoToMiddle, GoMinimum, GoDupa, GoMaximum, Complete } CalibrationStage;
         CalibrationStage cStage { Idle };
 
-        int m_MotionProgressTimerID {-1};
-        int m_HallSensorTimerID {-1};
+        ISwitch BacklashS[2];
+        ISwitchVectorProperty BacklashSP;
+        enum
+        {
+            BACKLASH_START,
+            BACKLASH_NEXT
+        };
+        IText BacklashMessageT[1] {};
+        ITextVectorProperty BacklashMessageTP;
+
+        typedef enum { BacklashIdle, BacklashMinimum, BacklashMaximum, BacklashComplete } BacklashStage;
+        BacklashStage bStage { BacklashIdle };
+
+        //        int m_MotionProgressTimerID {-1};
+        //        int m_HallSensorTimerID {-1};
+        INDI::Timer m_MotionProgressTimer;
+        INDI::Timer m_HallSensorTimer;
         bool m_IsSestoSenso2 { true };
         /////////////////////////////////////////////////////////////////////////////
         /// Static Helper Values
