@@ -60,21 +60,26 @@ bool DeepSkyDadFR1::initProperties()
     // Speed mode
     IUFillSwitch(&SpeedModeS[Slow], "SLOW", "Slow", ISS_OFF);
     IUFillSwitch(&SpeedModeS[Fast], "FAST", "Fast", ISS_OFF);
-    IUFillSwitchVector(&SpeedModeSP, SpeedModeS, 2, getDeviceName(), "Speed mode", "Speed mode", MAIN_CONTROL_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
-	
-	// Step mode
+    IUFillSwitchVector(&SpeedModeSP, SpeedModeS, 2, getDeviceName(), "Speed mode", "Speed mode", MAIN_CONTROL_TAB, IP_RW,
+                       ISR_1OFMANY, 0, IPS_IDLE);
+
+    // Step mode
     IUFillSwitch(&StepSizeS[One], "1", "1", ISS_OFF);
     IUFillSwitch(&StepSizeS[Two], "2", "1/2", ISS_OFF);
-	IUFillSwitch(&StepSizeS[Four], "4", "1/4", ISS_OFF);
+    IUFillSwitch(&StepSizeS[Four], "4", "1/4", ISS_OFF);
     IUFillSwitch(&StepSizeS[Eight], "8", "1/8", ISS_OFF);
-    IUFillSwitchVector(&StepSizeSP, StepSizeS, 4, getDeviceName(), "Step mode", "Step mode", MAIN_CONTROL_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
-	
+    IUFillSwitchVector(&StepSizeSP, StepSizeS, 4, getDeviceName(), "Step mode", "Step mode", MAIN_CONTROL_TAB, IP_RW,
+                       ISR_1OFMANY, 0, IPS_IDLE);
+
     // Firmware version
     IUFillText(&FirmwareT[0], "Version", "Version", nullptr);
     IUFillTextVector(&FirmwareTP, FirmwareT, 1, getDeviceName(), "Firmware", "Firmware", MAIN_CONTROL_TAB, IP_RO, 60, IPS_IDLE);
 
     serialConnection->setDefaultPort("/dev/ttyACM0");
-    serialConnection->registerHandshake([&]() { return Handshake(); });
+    serialConnection->registerHandshake([&]()
+    {
+        return Handshake();
+    });
     serialConnection->setDefaultBaudRate(Connection::Serial::B_115200);
     return true;
 }
@@ -91,7 +96,7 @@ bool DeepSkyDadFR1::updateProperties()
     }
     else
     {
-		deleteProperty(SpeedModeSP.name);
+        deleteProperty(SpeedModeSP.name);
         deleteProperty(StepSizeSP.name);
         deleteProperty(FirmwareTP.name);
     }
@@ -112,7 +117,7 @@ bool DeepSkyDadFR1::Handshake()
 
 bool DeepSkyDadFR1::ISNewSwitch(const char * dev, const char * name, ISState * states, char * names[], int n)
 {
-   if (dev != nullptr && strcmp(dev, getDeviceName()) == 0)
+    if (dev != nullptr && strcmp(dev, getDeviceName()) == 0)
     {
         if (strcmp(SpeedModeSP.name, name) == 0)
         {
@@ -146,7 +151,8 @@ bool DeepSkyDadFR1::ISNewSwitch(const char * dev, const char * name, ISState * s
             SpeedModeSP.s = IPS_OK;
             IDSetSwitch(&SpeedModeSP, nullptr);
             return true;
-        } else  if (strcmp(StepSizeSP.name, name) == 0)
+        }
+        else  if (strcmp(StepSizeSP.name, name) == 0)
         {
             int current_mode = IUFindOnSwitchIndex(&StepSizeSP);
 
@@ -187,8 +193,8 @@ bool DeepSkyDadFR1::ISNewSwitch(const char * dev, const char * name, ISState * s
 IPState DeepSkyDadFR1::MoveRotator(double angle)
 {
     char response[DSD_RES];
-	char cmd[DSD_CMD];
-    int angleInt = (int)(angle*100);
+    char cmd[DSD_CMD];
+    int angleInt = (int)(angle * 100);
     snprintf(cmd, DSD_CMD, "[STRG%d]", angleInt);
     if (!sendCommand(cmd, response) || !sendCommand("[SMOV]", response))
         return IPS_ALERT;
@@ -218,7 +224,7 @@ bool DeepSkyDadFR1::AbortRotator()
 bool DeepSkyDadFR1::ReverseRotator(bool enabled)
 {
     char response[DSD_RES];
-	char cmd[DSD_CMD];
+    char cmd[DSD_CMD];
     snprintf(cmd, DSD_CMD, "[SREV%d]", enabled ? 1 : 0);
     if (!sendCommand(cmd, response))
         return false;
@@ -234,8 +240,8 @@ bool DeepSkyDadFR1::ReverseRotator(bool enabled)
 bool DeepSkyDadFR1::SyncRotator(double angle)
 {
     char response[DSD_RES];
-	char cmd[DSD_CMD];
-    int angleInt = (int)(angle*100);
+    char cmd[DSD_CMD];
+    int angleInt = (int)(angle * 100);
     snprintf(cmd, DSD_CMD, "[SPOS%d]", angleInt);
     if (!sendCommand(cmd, response))
         return false;
@@ -260,29 +266,29 @@ bool DeepSkyDadFR1::getStatusData()
 {
     char response[DSD_RES];
 
-	int motorStatus;
+    int motorStatus;
     int motorPosition;
-	
-	if (!sendCommand("[GMOV]", response))
-		return false;
-	else
-		sscanf(response, "(%d)", &motorStatus);
-	
-	if (!sendCommand("[GPOS]", response))
-		return false;
-	else
-		sscanf(response, "(%d)", &motorPosition);
-	
+
+    if (!sendCommand("[GMOV]", response))
+        return false;
+    else
+        sscanf(response, "(%d)", &motorStatus);
+
+    if (!sendCommand("[GPOS]", response))
+        return false;
+    else
+        sscanf(response, "(%d)", &motorPosition);
+
 
 
     const IPState motionState = motorStatus == 1 ? IPS_BUSY : IPS_OK;
 
-    double motorPositionDouble = (double)motorPosition/(double)100;
+    double motorPositionDouble = (double)motorPosition / (double)100;
     if (std::abs(motorPositionDouble - GotoRotatorN[0].value) > 0.01 || GotoRotatorNP.s != motionState)
-	{
+    {
         GotoRotatorN[0].value = motorPositionDouble;
-		GotoRotatorNP.s = motionState;
-		IDSetNumber(&GotoRotatorNP, nullptr);
+        GotoRotatorNP.s = motionState;
+        IDSetNumber(&GotoRotatorNP, nullptr);
     }
 
     return true;
