@@ -63,6 +63,16 @@ const uint16_t Driver::IOP_SLEW_RATES[] = {1, 2, 8, 16, 64, 128, 256, 512, 1024}
 
 Driver::Driver(const char *deviceName): m_DeviceName(deviceName) {}
 
+bool Driver::sendCommandOk(const char *command)
+{
+    char res[IOP_BUFFER] = {0};
+
+    if (sendCommand(command, 1, res))
+        return res[0] == '1';
+
+    return false;
+}
+
 bool Driver::sendCommand(const char *command, int count, char *response, uint8_t timeout, uint8_t debugLog)
 {
     int errCode = 0;
@@ -88,13 +98,21 @@ bool Driver::sendCommand(const char *command, int count, char *response, uint8_t
     if (count == 0)
         return true;
 
-    if (count == -1)
-        errCode = tty_read_section(PortFD, res, '#', timeout, &nbytes_read);
-    else
-        errCode = tty_read(PortFD, res, count, timeout, &nbytes_read);
+    // Try to read twice in case of timeouts.
+    for (int i = 0; i < 2; i++)
+    {
+        if (count == -1)
+            errCode = tty_read_section(PortFD, res, '#', timeout, &nbytes_read);
+        else
+            errCode = tty_read(PortFD, res, count, timeout, &nbytes_read);
+
+        if (errCode == TTY_OK)
+            break;
+    }
 
     if (errCode != TTY_OK)
     {
+
         tty_error_msg(errCode, errMsg, MAXRBUF);
         DEBUGFDEVICE(m_DeviceName, INDI::Logger::DBG_ERROR, "Read Command Error: %s", errMsg);
         return false;
@@ -112,10 +130,7 @@ bool Driver::sendCommand(const char *command, int count, char *response, uint8_t
     if (response)
         strncpy(response, res, IOP_BUFFER);
 
-    if (count == -1 || (count == 1 && res[0] == '1') || count == nbytes_read)
-        return true;
-
-    return false;
+    return true;
 }
 
 bool Driver::checkConnection(int fd)
@@ -240,6 +255,13 @@ bool Driver::getStatus(IOPInfo *info)
         return false;
 
 
+    if (strlen(res) != 23)
+    {
+        DEBUGFDEVICE(m_DeviceName, INDI::Logger::DBG_ERROR, "%s: Expected 23 bytes but received %d.", __PRETTY_FUNCTION__,
+                     strlen(res));
+        return false;
+    }
+
     char longPart[16] = {0}, latPart[16] = {0};
     strncpy(longPart, res, 9);
     strncpy(latPart, res + 9, 8);
@@ -249,12 +271,12 @@ bool Driver::getStatus(IOPInfo *info)
 
     info->longitude    = arcsecLongitude / 360000.0;
     info->latitude     = arcsecLatitude / 360000.0 - 90.0;
-    info->gpsStatus    = (IOP_GPS_STATUS)(res[17] - '0');
-    info->systemStatus = (IOP_SYSTEM_STATUS)(res[18] - '0');
-    info->trackRate    = (IOP_TRACK_RATE)(res[19] - '0');
-    info->slewRate     = (IOP_SLEW_RATE)(res[20] - '0');
-    info->timeSource   = (IOP_TIME_SOURCE)(res[21] - '0');
-    info->hemisphere   = (IOP_HEMISPHERE)(res[22] - '0');
+    info->gpsStatus    = static_cast<IOP_GPS_STATUS>(res[17] - '0');
+    info->systemStatus = static_cast<IOP_SYSTEM_STATUS>(res[18] - '0');
+    info->trackRate    = static_cast<IOP_TRACK_RATE>(res[19] - '0');
+    info->slewRate     = static_cast<IOP_SLEW_RATE>(res[20] - '0');
+    info->timeSource   = static_cast<IOP_TIME_SOURCE>(res[21] - '0');
+    info->hemisphere   = static_cast<IOP_HEMISPHERE>(res[22] - '0');
 
     return true;
 }
@@ -331,20 +353,16 @@ bool Driver::startMotion(IOP_DIRECTION dir)
     {
         case IOP_N:
             return sendCommand(":mn#", 0);
-            break;
         case IOP_S:
             return sendCommand(":ms#", 0);
-            break;
         // JM 2020-10-12
         // We are reversing this since CEM120 moves CW when commanded WEST
         // leading to INCREASING RA, when it is expected to move CCW leading
         // to DECREASING RA
         case IOP_W:
             return sendCommand(":me#", 0);
-            break;
         case IOP_E:
             return sendCommand(":mw#", 0);
-            break;
     }
 
     return false;
@@ -356,13 +374,11 @@ bool Driver::stopMotion(IOP_DIRECTION dir)
     {
         case IOP_N:
         case IOP_S:
-            return sendCommand(":qD#");
-            break;
+            return sendCommandOk(":qD#");
 
         case IOP_W:
         case IOP_E:
-            return sendCommand(":qR#");
-            break;
+            return sendCommandOk(":qR#");
     }
 
     return false;
@@ -370,28 +386,28 @@ bool Driver::stopMotion(IOP_DIRECTION dir)
 
 bool Driver::findHome()
 {
-    return sendCommand(":MSH#");
+    return sendCommandOk(":MSH#");
 }
 
 bool Driver::gotoHome()
 {
-    return sendCommand(":MH#");
+    return sendCommandOk(":MH#");
 }
 
 bool Driver::setCurrentHome()
 {
-    return sendCommand(":SZP#");
+    return sendCommandOk(":SZP#");
 }
 
 /* v3.0 Added in control for PEC , Train and Data Integrity */
 bool Driver::setPECEnabled(bool enabled)
 {
-    return sendCommand(enabled ? ":SPP1#" : ":SPP0#");
+    return sendCommandOk(enabled ? ":SPP1#" : ":SPP0#");
 }
 
 bool Driver::setPETEnabled(bool enabled)
 {
-    return sendCommand(enabled ? ":SPR1#" : ":SPR0#");
+    return sendCommandOk(enabled ? ":SPR1#" : ":SPR0#");
 }
 
 bool Driver::getPETEnabled(bool enabled)
@@ -426,11 +442,11 @@ bool Driver::getPETEnabled(bool enabled)
 bool Driver::setSlewRate(IOP_SLEW_RATE rate)
 {
     char cmd[IOP_BUFFER] = {0};
-    snprintf(cmd, IOP_BUFFER, ":SR%d#", ((int)rate) + 1);
+    snprintf(cmd, IOP_BUFFER, ":SR%u#", static_cast<uint32_t>(rate + 1));
 
     simData.simInfo.slewRate = rate;
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setTrackMode(IOP_TRACK_RATE rate)
@@ -440,20 +456,15 @@ bool Driver::setTrackMode(IOP_TRACK_RATE rate)
     switch (rate)
     {
         case TR_SIDEREAL:
-            return sendCommand(":RT0#");
-            break;
+            return sendCommandOk(":RT0#");
         case TR_LUNAR:
-            return sendCommand(":RT1#");
-            break;
+            return sendCommandOk(":RT1#");
         case TR_SOLAR:
-            return sendCommand(":RT2#");
-            break;
+            return sendCommandOk(":RT2#");
         case TR_KING:
-            return sendCommand(":RT3#");
-            break;
+            return sendCommandOk(":RT3#");
         case TR_CUSTOM:
-            return sendCommand(":RT4#");
-            break;
+            return sendCommandOk(":RT4#");
     }
 
     return false;
@@ -465,9 +476,9 @@ bool Driver::setCustomRATrackRate(double rate)
         return false;
 
     char cmd[IOP_BUFFER] = {0};
-    snprintf(cmd, IOP_BUFFER, ":RR%05d#", static_cast<uint32_t>(rate * 10000));
+    snprintf(cmd, IOP_BUFFER, ":RR%05u#", static_cast<uint32_t>(rate * 10000));
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setGuideRate(double RARate, double DERate)
@@ -476,9 +487,9 @@ bool Driver::setGuideRate(double RARate, double DERate)
         return false;
 
     char cmd[IOP_BUFFER] = {0};
-    snprintf(cmd, IOP_BUFFER, ":RG%02d%02d#", static_cast<uint32_t>(RARate * 100), static_cast<uint32_t>(DERate * 100));
+    snprintf(cmd, IOP_BUFFER, ":RG%02u%02u#", static_cast<uint32_t>(RARate * 100), static_cast<uint32_t>(DERate * 100));
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::getGuideRate(double *RARate, double *DERate)
@@ -486,7 +497,7 @@ bool Driver::getGuideRate(double *RARate, double *DERate)
     char res[IOP_BUFFER] = {0};
 
     if (m_Simulation)
-        snprintf(res, IOP_BUFFER, "%02d%02d", static_cast<uint32_t>(simData.ra_guide_rate * 100),
+        snprintf(res, IOP_BUFFER, "%02u%02u", static_cast<uint32_t>(simData.ra_guide_rate * 100),
                  static_cast<uint32_t>(simData.de_guide_rate * 100));
     else if (sendCommand(":AG#", -1, res) == false)
         return false;
@@ -505,37 +516,38 @@ bool Driver::startGuide(IOP_DIRECTION dir, uint32_t ms)
 {
     char cmd[IOP_BUFFER] = {0};
     char dir_c = 0;
-    
-    // Sophie Taylor 2022-03-01
-    // TODO: This command set is deprecated, to be replaced with RA+/- and Dec+/- commands
-    // See https://www.ioptron.com/v/ASCOM/RS-232_Command_Language2014V310.pdf
+
     switch (dir)
     {
+        // Dec+
         case IOP_N:
-            dir_c = 'n';
+            dir_c = 'E';
             break;
 
+        // Dec-
         case IOP_S:
-            dir_c = 's';
+            dir_c = 'C';
             break;
 
+        // RA-
         case IOP_W:
-            dir_c = 'w';
+            dir_c = 'Q';
             break;
 
+        // RA+
         case IOP_E:
-            dir_c = 'e';
+            dir_c = 'S';
             break;
     }
 
-    snprintf(cmd, IOP_BUFFER, ":M%c%05d#", dir_c, ms);
+    snprintf(cmd, IOP_BUFFER, ":Z%c%05u#", dir_c, ms);
 
     return sendCommand(cmd, 0);
 }
 
 bool Driver::park()
 {
-    return sendCommand(":MP1#");
+    return sendCommandOk(":MP1#");
 }
 
 bool Driver::unpark()
@@ -543,7 +555,7 @@ bool Driver::unpark()
     //NB: This command only available in CEM120 series, CEM60 series, iEQ45 Pro, iEQ45 Pro
     //AA and iEQ30 Pro.
     setSimSytemStatus(ST_STOPPED);
-    return sendCommand(":MP0#");
+    return sendCommandOk(":MP0#");
 }
 
 bool Driver::setParkAz(double az)
@@ -555,7 +567,7 @@ bool Driver::setParkAz(double az)
 
     snprintf(cmd, IOP_BUFFER, ":SPA%09d#", ieqValue);
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setParkAlt(double alt)
@@ -567,7 +579,7 @@ bool Driver::setParkAlt(double alt)
     // Send as 0.01 arcsec resolution
     int ieqValue = static_cast<int>(alt * 60 * 60 * 100);
     snprintf(cmd, IOP_BUFFER, ":SPH%08d#", ieqValue);
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::abort()
@@ -575,7 +587,7 @@ bool Driver::abort()
     if (simData.simInfo.systemStatus == ST_SLEWING)
         simData.simInfo.systemStatus =  simData.simInfo.rememberSystemStatus;
 
-    return sendCommand(":Q#");
+    return sendCommandOk(":Q#");
 }
 
 bool Driver::slewNormal()
@@ -583,7 +595,7 @@ bool Driver::slewNormal()
     simData.simInfo.rememberSystemStatus = simData.simInfo.systemStatus;
     simData.simInfo.systemStatus = ST_SLEWING;
 
-    return sendCommand(":MS1#");
+    return sendCommandOk(":MS1#");
 }
 
 bool Driver::slewCWUp()
@@ -591,12 +603,12 @@ bool Driver::slewCWUp()
     simData.simInfo.rememberSystemStatus = simData.simInfo.systemStatus;
     simData.simInfo.systemStatus = ST_SLEWING;
 
-    return sendCommand(":MS2#");
+    return sendCommandOk(":MS2#");
 }
 
 bool Driver::sync()
 {
-    return sendCommand(":CM#");
+    return sendCommand(":CM#", 1);
 }
 
 bool Driver::setTrackEnabled(bool enabled)
@@ -617,9 +629,9 @@ bool Driver::setRA(double ra)
     simData.ra = ra;
 
     char cmd[IOP_BUFFER] = {0};
-    snprintf(cmd, IOP_BUFFER, ":SRA%09d#", casRA);
+    snprintf(cmd, IOP_BUFFER, ":SRA%09u#", casRA);
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setDE(double de)
@@ -631,9 +643,9 @@ bool Driver::setDE(double de)
     simData.de = de;
 
     char cmd[IOP_BUFFER] = {0};
-    snprintf(cmd, IOP_BUFFER, ":Sd%c%08d#", de >= 0 ? '+' : '-', casDE);
+    snprintf(cmd, IOP_BUFFER, ":Sd%c%08u#", de >= 0 ? '+' : '-', casDE);
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setLongitude(double longitude)
@@ -643,9 +655,9 @@ bool Driver::setLongitude(double longitude)
     simData.simInfo.longitude = longitude;
 
     char cmd[IOP_BUFFER] = {0};
-    snprintf(cmd, IOP_BUFFER, ":SLO%c%08d#", longitude >= 0 ? '+' : '-', casLongitude);
+    snprintf(cmd, IOP_BUFFER, ":SLO%c%08u#", longitude >= 0 ? '+' : '-', casLongitude);
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setLatitude(double latitude)
@@ -655,9 +667,9 @@ bool Driver::setLatitude(double latitude)
     simData.simInfo.latitude = latitude;
 
     char cmd[IOP_BUFFER] = {0};
-    snprintf(cmd, IOP_BUFFER, ":SLA%c%08d#", latitude >= 0 ? '+' : '-', casLatitude);
+    snprintf(cmd, IOP_BUFFER, ":SLA%c%08u#", latitude >= 0 ? '+' : '-', casLatitude);
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setUTCDateTime(double JD)
@@ -669,7 +681,7 @@ bool Driver::setUTCDateTime(double JD)
 
     simData.JD = JD;
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setUTCOffset(int offsetMinutes)
@@ -679,7 +691,7 @@ bool Driver::setUTCOffset(int offsetMinutes)
 
     simData.utc_offset_minutes = offsetMinutes;
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::setDaylightSaving(bool enabled)
@@ -689,7 +701,7 @@ bool Driver::setDaylightSaving(bool enabled)
 
     simData.day_light_saving = enabled;
 
-    return sendCommand(cmd);
+    return sendCommandOk(cmd);
 }
 
 bool Driver::getCoords(double *ra, double *de, IOP_PIER_STATE *pierState, IOP_CW_STATE *cwState)
@@ -697,20 +709,35 @@ bool Driver::getCoords(double *ra, double *de, IOP_PIER_STATE *pierState, IOP_CW
     char res[IOP_BUFFER] = {0};
     if (m_Simulation)
     {
-        snprintf(res, IOP_BUFFER, "%c%08d%09d%d%d", (simData.de >= 0 ? '+' : '-'),
+        snprintf(res, IOP_BUFFER, "%c%08u%09u%d%d", (simData.de >= 0 ? '+' : '-'),
                  static_cast<uint32_t>(fabs(simData.de) * 60 * 60 * 100),
                  static_cast<uint32_t>(simData.ra * 15 * 60 * 60 * 100), simData.pier_state, simData.cw_state);
     }
     else if (sendCommand(":GEP#", -1, res, IOP_TIMEOUT, INDI::Logger::DBG_EXTRA_1) == false)
         return false;
 
+    if (strlen(res) != 20)
+    {
+        DEBUGFDEVICE(m_DeviceName, INDI::Logger::DBG_ERROR, "%s: Expected 20 bytes but received %d.", __PRETTY_FUNCTION__,
+                     strlen(res));
+        return false;
+    }
+
     char deStr[16] = {0}, raStr[16] = {0};
 
     strncpy(deStr, res, 9);
     strncpy(raStr, res + 9, 9);
 
-    *de = atoi(deStr) / (60.0 * 60.0 * 100.0);
-    *ra = atoi(raStr) / (15.0 * 60.0 * 60.0 * 100.0);
+    try
+    {
+        *de = std::atoi(deStr) / (60.0 * 60.0 * 100.0);
+        *ra = std::atoi(raStr) / (15.0 * 60.0 * 60.0 * 100.0);
+    }
+    catch(...)
+    {
+        DEBUGFDEVICE(m_DeviceName, INDI::Logger::DBG_ERROR, "Failed to parse coordinates RA: %s DE: %s", raStr, deStr);
+        return false;
+    }
 
     *pierState = static_cast<IOP_PIER_STATE>(res[18] - '0');
     *cwState   = static_cast<IOP_CW_STATE>(res[19] - '0');
@@ -730,6 +757,13 @@ bool Driver::getUTCDateTime(double *JD, int *utcOffsetMinutes, bool *dayLightSav
     else if (sendCommand(":GUT#", -1, res) == false)
         return false;
 
+    if (strlen(res) != 18)
+    {
+        DEBUGFDEVICE(m_DeviceName, INDI::Logger::DBG_ERROR, "%s: Expected 18 bytes but received %d.", __PRETTY_FUNCTION__,
+                     strlen(res));
+        return false;
+    }
+
     char offsetStr[16] = {0}, JDStr[16] = {0};
 
     strncpy(offsetStr, res, 4);
@@ -738,8 +772,16 @@ bool Driver::getUTCDateTime(double *JD, int *utcOffsetMinutes, bool *dayLightSav
     *utcOffsetMinutes = atoi(offsetStr);
     *dayLightSaving   = (res[4] == '1');
 
-    uint64_t iopJD = std::stoull(JDStr);
-    *JD = (iopJD / 8.64e+7) + J2000;
+    try
+    {
+        uint64_t iopJD = std::stoull(JDStr);
+        *JD = (iopJD / 8.64e+7) + J2000;
+    }
+    catch(...)
+    {
+        DEBUGFDEVICE(m_DeviceName, INDI::Logger::DBG_ERROR, "Failed to parse JD String: %s", JDStr);
+        return false;
+    }
 
     return true;
 }
@@ -754,14 +796,21 @@ bool Driver::getMeridianBehavior(IOP_MB_STATE &action, uint8_t &degrees)
     else if (sendCommand(":GMT#", -1, res) == false)
         return false;
 
-    action = static_cast<IOP_MB_STATE>(res[0] - '0');
-    degrees = std::stoi(res + 1);
+    try
+    {
+        action = static_cast<IOP_MB_STATE>(res[0] - '0');
+        degrees = std::stoi(res + 1);
+    }
+    catch(...)
+    {
+        DEBUGFDEVICE(m_DeviceName, INDI::Logger::DBG_ERROR, "Failed to parse MF Behavior: %s", res);
+        return false;
+    }
     return true;
 }
 
 bool Driver::setMeridianBehavior(IOP_MB_STATE action, uint8_t degrees)
 {
-    char cmd[IOP_BUFFER] = {0};
     if (m_Simulation)
     {
         simData.mb_state = action;
@@ -770,8 +819,9 @@ bool Driver::setMeridianBehavior(IOP_MB_STATE action, uint8_t degrees)
     }
     else
     {
+        char cmd[IOP_BUFFER] = {0};
         snprintf(cmd, IOP_BUFFER, ":SMT%d%02d#", action, degrees);
-        return sendCommand(cmd);
+        return sendCommandOk(cmd);
     }
 }
 
