@@ -35,7 +35,7 @@
 #include <strings.h>
 #include <termios.h>
 #include <math.h>
-#include <libnova.h>
+#include <libnova/libnova.h>
 
 #define PRODUCT_TAB   "Product"
 #define ALIGNMENT_TAB "Alignment"
@@ -74,7 +74,8 @@ LX200_10MICRON::LX200_10MICRON() : LX200Generic()
         TELESCOPE_HAS_TRACK_MODE |
         TELESCOPE_CAN_CONTROL_TRACK |
         TELESCOPE_HAS_TRACK_RATE |
-        TELESCOPE_CAN_TRACK_SATELLITE
+        TELESCOPE_CAN_TRACK_SATELLITE,
+        4
     );
 
     setVersion(1, 0);
