@@ -23,8 +23,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     ===========================================
-    
+
     Version not yet updated/No INDI release:
+    Version 1.17
+    - fixed setMaxElevationLimit / setMinElevationLimit
     Version 1.16
     - fixed uninitialized UTC structure thanks to Norikyu
     Version 1.15
@@ -46,15 +48,15 @@
     - Cleanup and completely control TrackState. (Should eliminate various issues.)
     - Behind the scenes: More consistent command declarations (Should eliminate a type of error that's happened in the past when changing commands.)
     - Don't report capability for PierSide and PEC unless supported (This will cause a call to updateProperties so a bunch of messages will be repeated.)
-    - From the last, move where the SlewRate values are defined to updateProperties, vs initProperties so that the extra calls to updateProperties don't mangle it. 
+    - From the last, move where the SlewRate values are defined to updateProperties, vs initProperties so that the extra calls to updateProperties don't mangle it.
     - TMC driver reports are now human readable.
-    - Detects OnStep or OnStepX version (doesn't do much with it.) 
+    - Detects OnStep or OnStepX version (doesn't do much with it.)
 
 
     Version 1.11: (INDI 1.9.2)
-    - Fixed one issue with tracking (Jamie Flinn/jamiecflinn) 
+    - Fixed one issue with tracking (Jamie Flinn/jamiecflinn)
     Version 1.10: (finalized: INDI 1.9.1)
-    - Weather support for setting temperature/humidity/pressure, values will be overridden in OnStep by any sensor values. 
+    - Weather support for setting temperature/humidity/pressure, values will be overridden in OnStep by any sensor values.
     - Ability to swap primary focuser.
     - High precision on location, and not overridding GPS even when marked for Mount > KStars.
     - Added Rotator & De-Rotator Support
@@ -194,14 +196,14 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
         *  2 = Fork Alt
         *  3 = Alt Azm
         */
-        
+
         virtual bool sendScopeTime() override;
         virtual bool sendScopeLocation() override;
         virtual bool setUTCOffset(double offset) override; //azwing fix after change in lx200driver.cpp
-        
+
         // Goto
         virtual bool Goto(double ra, double dec) override;
-        
+
         //FocuserInterface
 
         IPState MoveFocuser(FocusDirection dir, int speed, uint16_t duration) override;
@@ -212,17 +214,17 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
         //End FocuserInterface
 
         //RotatorInterface
-        
+
         IPState MoveRotator(double angle) override;
-//         bool SyncRotator(double angle) override;
+        //         bool SyncRotator(double angle) override;
         IPState HomeRotator() override;
-//         bool ReverseRotator(bool enabled) override;
+        //         bool ReverseRotator(bool enabled) override;
         bool AbortRotator() override;
         bool SetRotatorBacklash (int32_t steps) override;
         bool SetRotatorBacklashEnabled(bool enabled) override;
-        
-        //End RotatorInterface        
-        
+
+        //End RotatorInterface
+
         //PECInterface
         //axis 0=RA, 1=DEC, others?
         IPState StopPECPlayback (int axis);
@@ -248,7 +250,7 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
          * @param stars Number of stars to be included. If stars is more than the controller supports, it will be reduced.
          * @return IPS_BUSY if no issues, IPS_ALERT if commands don't get the expected response.
          */
-        
+
         IPState AlignAddStar();
         IPState AlignDone();
         IPState AlignWrite();
@@ -268,12 +270,13 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
         int flushIO(int fd);
         int getCommandSingleCharResponse(int fd, char *data, const char *cmd); //Reimplemented from getCommandString
         int getCommandSingleCharErrorOrLongResponse(int fd, char *data, const char *cmd); //Reimplemented from getCommandString
-        int getCommandDoubleResponse(int fd, double *value, char *data, const char *cmd); //Reimplemented from getCommandString Will return a double, and raw value.
+        int getCommandDoubleResponse(int fd, double *value, char *data,
+                                     const char *cmd); //Reimplemented from getCommandString Will return a double, and raw value.
         int getCommandIntResponse(int fd, int *value, char *data, const char *cmd);
-        int  setMaxElevationLimit(int fd, int max);
+        int  setMinElevationLimit(int fd, int max);
         int OSUpdateFocuser(); //Return = 0 good, -1 = Communication error
         int OSUpdateRotator(); //Return = 0 good, -1 = Communication error
-        
+
         ITextVectorProperty ObjectInfoTP;
         IText ObjectInfoT[1] {};
 
@@ -300,16 +303,16 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
 
         ITextVectorProperty VersionTP;
         IText VersionT[5] {};
-        
+
         OnStepVersion OnStepMountVersion = OSV_UNKNOWN;
-        
+
         long int OSTimeoutSeconds = 0;
         long int OSTimeoutMicroSeconds = 100000;
 
         // OnStep Status controls
         ITextVectorProperty OnstepStatTP;
         IText OnstepStat[11] {};
-        
+
         bool TMCDrivers = true; //Set to false if it doesn't detect TMC_SPI reporting. (Small delay on connection/first update)
         bool OSHighPrecision = false;
 
@@ -318,7 +321,7 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
         bool OSFocuser1 = false;
         ISwitchVectorProperty OSFocus1InitializeSP;
         ISwitch OSFocus1InitializeS[4];
-        
+
         int OSNumFocusers = 0;
         ISwitchVectorProperty OSFocusSelectSP;
         ISwitch OSFocusSelectS[9];
@@ -340,11 +343,11 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
         bool OSRotator1 = false; //Change to false after detection code
         ISwitchVectorProperty OSRotatorRateSP;
         ISwitch OSRotatorRateS[4]; //Set rate
-        
+
         ISwitchVectorProperty OSRotatorDerotateSP;
         ISwitch OSRotatorDerotateS[2]; //On or Off
-        
-        
+
+
 
         int IsTracking = 0;
 
@@ -434,7 +437,8 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
         // Weather support
         // NOTE: Much is handled by WeatherInterface, these controls are mainly for setting values which are not detected
         // As of right now, if there is a sensor the values will be overwritten on the next update
-        bool OSCpuTemp_good = true; //This can fail on some processors and take the timeout before an update, so if it fails, don't check again.
+        bool OSCpuTemp_good =
+            true; //This can fail on some processors and take the timeout before an update, so if it fails, don't check again.
 
 
         INumberVectorProperty OSSetTemperatureNP;
@@ -454,27 +458,27 @@ class LX200_OnStep : public LX200Generic, public INDI::WeatherInterface, public
             return IPS_OK;
         }
 
-        
+
         /**
          * @brief SyncParkStatus Update the state and switches for parking
          * @param isparked True if parked, false otherwise.
          */
         virtual void SyncParkStatus(bool isparked) override;
-        
+
         /**
          * @brief SetParked Change the mount parking status. The data park file (stored in
          * ~/.indi/ParkData.xml) is updated in the process.
          * @param isparked set to true if parked, false otherwise.
          */
         virtual void SetParked(bool isparked) override;
-        
+
         /**
-         * @brief PrintTrackState will print to the debug log the status of TrackState if 
+         * @brief PrintTrackState will print to the debug log the status of TrackState if
          * DEBUG_TRACKSTATE is defined otherwise it will simply return.
          */
-// #define DEBUG_TRACKSTATE
+        // #define DEBUG_TRACKSTATE
         void PrintTrackState();
-        
+
     private:
         int currentCatalog;
         int currentSubCatalog;
