@@ -37,6 +37,7 @@ class LX200Gemini : public LX200Generic
         virtual void ISGetProperties(const char *dev) override;
         virtual bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n) override;
         virtual bool ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n) override;
+        virtual bool ISNewText(const char *dev, const char *name, char **texts, char **names, int n) override;
 
     protected:
         virtual const char *getDefaultName() override;
@@ -60,12 +61,13 @@ class LX200Gemini : public LX200Generic
         virtual bool saveConfigItems(FILE *fp) override;
 
     private:
+        void syncPec();
         void syncSideOfPier();
         bool sleepMount();
         bool wakeupMount();
 
-        bool getGeminiProperty(uint8_t propertyNumber, char* value);
-        bool setGeminiProperty(uint8_t propertyNumber, char* value);
+        bool getGeminiProperty(uint32_t propertyNumber, char* value);
+        bool setGeminiProperty(uint32_t propertyNumber, char* value);
 
         // Checksum for private commands
         uint8_t calculateChecksum(char *cmd);
@@ -79,7 +81,10 @@ class LX200Gemini : public LX200Generic
         INumber MoveSpeedN[1];
         INumberVectorProperty MoveSpeedNP;
 
-        INumber GuidingSpeedN[1];
+        INumber GuidingSpeedBothN[1];
+        INumberVectorProperty GuidingSpeedBothNP;
+
+        INumber GuidingSpeedN[2];
         INumberVectorProperty GuidingSpeedNP;
 
         INumber CenteringSpeedN[1];
@@ -87,6 +92,47 @@ class LX200Gemini : public LX200Generic
 
         ISwitch ParkSettingsS[3];
         ISwitchVectorProperty ParkSettingsSP;
+
+        ITextVectorProperty PECCounterTP;
+        IText PECCounterT[1];
+
+        ISwitchVectorProperty PECControlSP;
+        ISwitch PECControlS[2];
+
+        ITextVectorProperty PECStateTP;
+        IText PECStateT[6] {};
+  
+        INumber PECMaxStepsN[1];
+        INumberVectorProperty PECMaxStepsNP;
+  
+        INumber ServoPrecisionN[2];
+        INumberVectorProperty ServoPrecisionNP;
+
+        INumber PECEnableAtBootN[1];
+        INumberVectorProperty PECEnableAtBootNP;
+
+        INumber PECGuidingSpeedN[1];
+        INumberVectorProperty PECGuidingSpeedNP;
+
+        ISwitch FlipControlS[2];
+        ISwitchVectorProperty FlipControlSP;
+
+        INumber FlipPositionN[4];
+        INumberVectorProperty FlipPositionNP;
+  
+        ITextVectorProperty VersionTP;
+        IText VersionT[5] {};
+
+        float gemini_software_level_;
+
+        enum
+        {
+	 FIRMWARE_DATE,
+	 FIRMWARE_TIME,
+	 FIRMWARE_LEVEL,
+	 FIRMWARE_NAME
+	};
+  
         enum
         {
             PARK_HOME,
@@ -94,6 +140,39 @@ class LX200Gemini : public LX200Generic
             PARK_ZENITH
         };
 
+        enum
+        {
+            GUIDING_BOTH,
+        };
+
+        enum
+        {
+            GUIDING_WE,
+            GUIDING_NS
+        };
+
+        enum
+        {
+            PEC_START_TRAINING,
+            PEC_ABORT_TRAINING
+        };
+
+        enum
+	{
+	    PEC_STATUS_ACTIVE,
+	    PEC_STATUS_FRESH_TRAINED,
+	    PEC_STATUS_TRAINING_IN_PROGRESS,
+	    PEC_STATUS_TRAINING_COMPLETED,
+	    PEC_STATUS_WILL_TRAIN,
+	    PEC_STATUS_DATA_AVAILABLE
+	};
+
+        enum
+        {
+            SERVO_RA,
+            SERVO_DEC,
+        };
+
         ISwitch StartupModeS[3];
         ISwitchVectorProperty StartupModeSP;
         enum
@@ -129,6 +208,27 @@ class LX200Gemini : public LX200Generic
             PARK_IN_PROGRESS
         };
 
+        enum FlipPointState
+	{
+	    DISABLED,
+	    FLIP_EAST,
+	    FLIP_WEST
+	};
+
+        enum FlipPointControl
+	{
+	    FLIP_EAST_CONTROL,
+	    FLIP_WEST_CONTROL
+	};
+
+        enum FlipPointValue
+	{
+	    FLIP_EAST_DEGREE_VALUE,
+	    FLIP_EAST_MIN_VALUE,
+	    FLIP_WEST_DEGREE_VALUE,
+	    FLIP_WEST_MIN_VALUE
+	};
+
         const uint8_t GEMINI_TIMEOUT = 3;
 
         void setTrackState(INDI::Telescope::TelescopeStatus state);
