@@ -1,10 +1,14 @@
 /*******************************************************************************
  Copyright(c) 2017 Jasem Mutlaq. All rights reserved.
+ 2021 Chris Lewicki. Refactor of TCP connections and error handling
 
- Driver for using TheSky6 Pro Scripted operations for mounts via the TCP server.
- While this technically can operate any mount connected to the TheSky6 Pro, it is
+ Driver for using TheSkyX Pro Scripted operations for mounts via the TCP server.
+ While this technically can operate any mount connected to the TheSkyX Pro, it is
  intended for Paramount mounts control.
 
+ Ref TheSky Functions:
+ https://www.bisque.com/wp-content/scripttheskyx/classsky6_r_a_s_c_o_m_tele.html
+
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License version 2 as published by the Free Software Foundation.
@@ -20,6 +24,15 @@
  Boston, MA 02110-1301, USA.
 *******************************************************************************/
 
+/*******************************************************************************
+ * TODO for improving / completing the driver
+ *
+ * 1. SlewToAZAlt()
+ * 2. GetAzAlt()
+ * 3. (3) Presets for SlewToAZAlt positions
+ * 4. DoCommand(16) get/set atmospheric pressure for interfacing with other INDI devices
+*******************************************************************************/
+
 #include "paramount.h"
 
 #include "indicom.h"
@@ -30,7 +43,7 @@
 #include <cmath>
 #include <cstring>
 #include <memory>
-#include <regex>
+#include <termios.h>
 
 // We declare an auto pointer to Paramount.
 std::unique_ptr<Paramount> paramount_mount(new Paramount());
@@ -51,69 +64,44 @@ std::unique_ptr<Paramount> paramount_mount(new Paramount());
 #define RA_AXIS  0
 #define DEC_AXIS 1
 
-#define STELLAR_DAY        86164.098903691
-#define TRACKRATE_SIDEREAL ((360.0 * 3600.0) / STELLAR_DAY)
-#define SOLAR_DAY          86400
-#define TRACKRATE_SOLAR    ((360.0 * 3600.0) / SOLAR_DAY)
-#define TRACKRATE_LUNAR    14.511415
-
 /* Preset Slew Speeds */
 #define SLEWMODES 9
 const double slewspeeds[SLEWMODES] = { 1.0, 2.0, 4.0, 8.0, 32.0, 64.0, 128.0, 256.0, 512.0 };
 
-void ISPoll(void *p);
-
-void ISGetProperties(const char *dev)
-{
-    paramount_mount->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    paramount_mount->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    paramount_mount->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    paramount_mount->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-void ISSnoopDevice(XMLEle *root)
-{
-    paramount_mount->ISSnoopDevice(root);
-}
-
 Paramount::Paramount()
 {
+    setVersion(1, 4);
+
     DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
 
     SetTelescopeCapability(TELESCOPE_CAN_PARK | TELESCOPE_CAN_SYNC | TELESCOPE_CAN_GOTO | TELESCOPE_CAN_ABORT |
                            TELESCOPE_HAS_TIME | TELESCOPE_HAS_LOCATION | TELESCOPE_HAS_TRACK_MODE | TELESCOPE_HAS_TRACK_RATE |
-                           TELESCOPE_CAN_CONTROL_TRACK,
+                           TELESCOPE_CAN_CONTROL_TRACK | TELESCOPE_HAS_PIER_SIDE,
                            9);
     setTelescopeConnection(CONNECTION_TCP);
+
+    m_NSTimer.setSingleShot(true);
+    m_WETimer.setSingleShot(true);
+
+    // Called when timer is up
+    m_NSTimer.callOnTimeout([this]()
+    {
+        GuideNSNP.s = IPS_IDLE;
+        GuideNSN[0].value = GuideNSN[1].value = 0;
+        IDSetNumber(&GuideNSNP, nullptr);
+    });
+
+    m_WETimer.callOnTimeout([this]()
+    {
+        GuideWENP.s = IPS_IDLE;
+        GuideWEN[0].value = GuideWEN[1].value = 0;
+        IDSetNumber(&GuideWENP, nullptr);
+    });
 }
 
 const char *Paramount::getDefaultName()
 {
-    return (const char *)"Paramount";
+    return "Paramount";
 }
 
 bool Paramount::initProperties()
@@ -147,28 +135,11 @@ bool Paramount::initProperties()
     IUFillSwitchVector(&HomeSP, HomeS, 1, getDeviceName(), "TELESCOPE_HOME", "Homing", MAIN_CONTROL_TAB, IP_RW, ISR_ATMOST1, 60,
                        IPS_IDLE);
     // Tracking Mode
-#if 0
-    IUFillSwitch(&TrackModeS[TRACK_SIDEREAL], "TRACK_SIDEREAL", "Sidereal", ISS_OFF);
-    IUFillSwitch(&TrackModeS[TRACK_SOLAR], "TRACK_SOLAR", "Solar", ISS_OFF);
-    IUFillSwitch(&TrackModeS[TRACK_LUNAR], "TRACK_LUNAR", "Lunar", ISS_OFF);
-    IUFillSwitch(&TrackModeS[TRACK_CUSTOM], "TRACK_CUSTOM", "Custom", ISS_OFF);
-    IUFillSwitchVector(&TrackModeSP, TrackModeS, 4, getDeviceName(), "TELESCOPE_TRACK_MODE", "Track Mode",
-                       MAIN_CONTROL_TAB, IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
-#endif
-
     AddTrackMode("TRACK_SIDEREAL", "Sidereal", true);
     AddTrackMode("TRACK_SOLAR", "Solar");
     AddTrackMode("TRACK_LUNAR", "Lunar");
     AddTrackMode("TRACK_CUSTOM", "Custom");
 
-    // Custom Tracking Rate
-#if 0
-    IUFillNumber(&TrackRateN[0], "TRACK_RATE_RA", "RA (arcsecs/s)", "%.6f", -16384.0, 16384.0, 0.000001, 15.041067);
-    IUFillNumber(&TrackRateN[1], "TRACK_RATE_DE", "DE (arcsecs/s)", "%.6f", -16384.0, 16384.0, 0.000001, 0);
-    IUFillNumberVector(&TrackRateNP, TrackRateN, 2, getDeviceName(), "TELESCOPE_TRACK_RATE", "Track Rates",
-                       MAIN_CONTROL_TAB, IP_RW, 60, IPS_IDLE);
-#endif
-
     // Let's simulate it to be an F/7.5 120mm telescope with 50m 175mm guide scope
     ScopeParametersN[0].value = 120;
     ScopeParametersN[1].value = 900;
@@ -185,13 +156,8 @@ bool Paramount::initProperties()
 
     addAuxControls();
 
-    double longitude = 0, latitude = 90;
-    // Get value from config file if it exists.
-    IUGetConfigNumber(getDeviceName(), "GEOGRAPHIC_COORD", "LONG", &longitude);
-    currentRA  = get_local_sidereal_time(longitude);
-    IUGetConfigNumber(getDeviceName(), "GEOGRAPHIC_COORD", "LAT", &latitude);
-    currentDEC = latitude > 0 ? 90 : -90;
-
+    currentRA  = get_local_sidereal_time(LocationN[LOCATION_LONGITUDE].value);
+    currentDEC = LocationN[LOCATION_LATITUDE].value > 0 ? 90 : -90;
     return true;
 }
 
@@ -213,14 +179,14 @@ bool Paramount::updateProperties()
             TrackState = SCOPE_IDLE;
         }
 
-        //defineSwitch(&TrackModeSP);
-        //defineNumber(&TrackRateNP);
+        //defineProperty(&TrackModeSP);
+        //defineProperty(&TrackRateNP);
 
-        defineNumber(&JogRateNP);
+        defineProperty(&JogRateNP);
 
-        defineNumber(&GuideNSNP);
-        defineNumber(&GuideWENP);
-        defineNumber(&GuideRateNP);
+        defineProperty(&GuideNSNP);
+        defineProperty(&GuideWENP);
+        defineProperty(&GuideRateNP);
 
         // Initial HA to 0 and currentDEC (+90 or -90)
         if (InitPark())
@@ -240,7 +206,7 @@ bool Paramount::updateProperties()
 
         SetParked(isTheSkyParked());
 
-        defineSwitch(&HomeSP);
+        defineProperty(&HomeSP);
     }
     else
     {
@@ -258,6 +224,18 @@ bool Paramount::updateProperties()
     return true;
 }
 
+/*******************************************************************************
+* Note that for all successful TheSky TCP requests, the following string is
+* prepended to the result:
+*
+*    |No error. Error = 0.
+*
+* This is true everwhere except for the Handshake(), which just returns "1" on success.
+*
+* In order to know when the response is complete, we append the # character in
+* Javascript commands and read from the port until the # character is reached.
+*******************************************************************************/
+
 bool Paramount::Handshake()
 {
     if (isSimulation())
@@ -270,37 +248,26 @@ bool Paramount::Handshake()
             "/* Java Script */"
             "var Out;"
             "sky6RASCOMTele.ConnectAndDoNotUnpark();"
-            "Out = sky6RASCOMTele.IsConnected;",
+            "Out = sky6RASCOMTele.IsConnected + '#';",
             MAXRBUF);
 
     LOGF_DEBUG("CMD: %s", pCMD);
 
     if ((rc = tty_write_string(PortFD, pCMD, &nbytes_written)) != TTY_OK)
     {
-        LOG_ERROR("Error writing to TheSky6 TCP server.");
+        LOGF_ERROR("Error writing Handshake to TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
-    // Should we read until we encounter string terminator? or what?
-    if (static_cast<int>(rc == tty_read_section(PortFD, pRES, '\0', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
+    if ((rc = tty_read_section(PortFD, pRES, '#', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
     {
-        LOG_ERROR("Error reading from TheSky6 TCP server.");
+        LOGF_ERROR("Error reading Handshake from TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
-    LOGF_DEBUG("RES: %s", pRES);
-    int isTelescopeConnected = -1;
-
-    std::regex rgx(R"((\d+)\|(.+)\. Error = (\d+)\.)");
-    std::smatch match;
-    std::string input(pRES);
-    if (std::regex_search(input, match, rgx))
-        isTelescopeConnected = atoi(match.str(1).c_str());
-
-    if (isTelescopeConnected <= 0)
+    if (strcmp(pRES, "1#") != 0)
     {
-        LOGF_ERROR("Error connecting to telescope: %s (%d).", match.str(1).c_str(),
-                   atoi(match.str(2).c_str()));
+        LOGF_ERROR("Error connecting to TheSky. Result: %s", pRES);
         return false;
     }
 
@@ -309,58 +276,83 @@ bool Paramount::Handshake()
 
 bool Paramount::getMountRADE()
 {
-    int rc = 0, nbytes_written = 0, nbytes_read = 0, errorCode = 0;
+    int rc = 0, nbytes_written = 0, nbytes_read = 0;
     char pCMD[MAXRBUF] = {0}, pRES[MAXRBUF] = {0};
+    double SkyXRA = 0., SkyXDEC = 0.;
 
-    //"if (sky6RASCOMTele.IsConnected==0) sky6RASCOMTele.Connect();"
     strncpy(pCMD,
             "/* Java Script */"
             "var Out;"
             "sky6RASCOMTele.GetRaDec();"
-            "Out = String(sky6RASCOMTele.dRa) + ',' + String(sky6RASCOMTele.dDec);",
+            "Out = String(sky6RASCOMTele.dRa) + ',' + String(sky6RASCOMTele.dDec) + '#';",
             MAXRBUF);
 
     LOGF_DEBUG("CMD: %s", pCMD);
 
     if ((rc = tty_write_string(PortFD, pCMD, &nbytes_written)) != TTY_OK)
     {
-        LOG_ERROR("Error writing to TheSky6 TCP server.");
+        LOGF_ERROR("Error writing GetRaDec to TheSkyX TCP server. Response: %d", rc);
         return false;
     }
 
-    // Should we read until we encounter string terminator? or what?
-    if (static_cast<int>(rc == tty_read_section(PortFD, pRES, '\0', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
+    if ((rc = tty_read_section(PortFD, pRES, '#', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
     {
-        LOG_ERROR("Error reading from TheSky6 TCP server.");
+        LOGF_ERROR("Error reading GetRaDec from TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
     LOGF_DEBUG("RES: %s", pRES);
 
-    std::regex rgx(R"((.+),(.+)\|(.+)\. Error = (\d+)\.)");
-    std::smatch match;
-    std::string input(pRES);
-    bool coordsOK = false;
-
-    if (std::regex_search(input, match, rgx))
+    // Read results successfully into temporary values before committing
+    if (sscanf(pRES, "|No error. Error = 0.%lf,%lf#", &SkyXRA, &SkyXDEC) == 2)
     {
-        errorCode = atoi(match.str(4).c_str());
-
-        if (errorCode == 0)
-        {
-            currentRA  = atof(match.str(1).c_str());
-            currentDEC = atof(match.str(2).c_str());
-            coordsOK   = true;
-        }
+        currentRA  = SkyXRA;
+        currentDEC = SkyXDEC;
+        return true;
     }
 
-    if (coordsOK)
-        return true;
-
-    LOGF_ERROR("Error reading coordinates %s (%d).", match.str(3).c_str(), errorCode);
+    LOGF_ERROR("Error reading coordinates. Result: %s", pRES);
     return false;
 }
 
+INDI::Telescope::TelescopePierSide Paramount::getPierSide()
+{
+    int rc = 0, nbytes_written = 0, nbytes_read = 0;
+    char pCMD[MAXRBUF] = {0}, pRES[MAXRBUF] = {0};
+    int SkyXPierSide = -1;
+
+    strncpy(pCMD,
+            "/* Java Script */"
+            "var Out;"
+            "sky6RASCOMTele.DoCommand(11, \"Pier Side\");"
+            "Out = sky6RASCOMTele.DoCommandOutput + '#';",
+            MAXRBUF);
+
+    LOGF_DEBUG("CMD: %s", pCMD);
+
+    if ((rc = tty_write_string(PortFD, pCMD, &nbytes_written)) != TTY_OK)
+    {
+        LOGF_ERROR("Error writing DoCommand(Pier Side) to TheSkyX TCP server. Result: %d", rc);
+        return PIER_UNKNOWN;
+    }
+
+    if ((rc = tty_read_section(PortFD, pRES, '#', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
+    {
+        LOGF_ERROR("Error reading Pier Side from TheSkyX TCP server. Result: %d", rc);
+        return PIER_UNKNOWN;
+    }
+
+    LOGF_DEBUG("RES: %s", pRES);
+
+    if (sscanf(pRES, "|No error. Error = 0.%d#", &SkyXPierSide) == 1)
+    {
+        return SkyXPierSide == 1 ? PIER_WEST : PIER_EAST;
+    }
+
+    LOGF_ERROR("Error reading Pier Side. Result: %s", pRES);
+    return PIER_UNKNOWN;
+}
+
 bool Paramount::ReadScopeStatus()
 {
     if (isSimulation())
@@ -371,7 +363,7 @@ bool Paramount::ReadScopeStatus()
 
     if (TrackState == SCOPE_SLEWING)
     {
-        // Check if LX200 is done slewing
+        // Check if Scope is done slewing
         if (isSlewComplete())
         {
             TrackState = SCOPE_TRACKING;
@@ -388,14 +380,10 @@ bool Paramount::ReadScopeStatus()
     }
     else if (TrackState == SCOPE_PARKING)
     {
-        if (isSlewComplete())
+        if (isTheSkyParked())
         {
             SetParked(true);
-            //LOG_INFO("Mount is parked. Disconnecting...");
-            //Disconnect();
         }
-
-        //return true;
     }
 
     if (!getMountRADE())
@@ -408,6 +396,8 @@ bool Paramount::ReadScopeStatus()
 
     DEBUGF(DBG_SCOPE, "Current RA: %s Current DEC: %s", RAStr, DecStr);
 
+    setPierSide(getPierSide());
+
     NewRaDec(currentRA, currentDEC);
     return true;
 }
@@ -421,16 +411,6 @@ bool Paramount::Goto(double r, double d)
     fs_sexa(RAStr, targetRA, 2, 3600);
     fs_sexa(DecStr, targetDEC, 2, 3600);
 
-    ln_equ_posn lnradec { 0, 0 };
-
-    lnradec.ra  = (currentRA * 360) / 24.0;
-    lnradec.dec = currentDEC;
-
-    //get_hrz_from_equ(&lnradec, &lnobserver, ln_get_julian_from_sys(), &lnaltaz);
-    /* libnova measures azimuth from south towards west */
-    //    double current_az = range360(lnaltaz.az + 180);
-    //double current_alt =lnaltaz.alt;
-
     char pCMD[MAXRBUF] = {0};
     snprintf(pCMD, MAXRBUF,
              "sky6RASCOMTele.Asynchronous = true;"
@@ -442,55 +422,44 @@ bool Paramount::Goto(double r, double d)
 
     TrackState = SCOPE_SLEWING;
 
-    //EqNP.s = IPS_BUSY;
-
     LOGF_INFO("Slewing to RA: %s - DEC: %s", RAStr, DecStr);
     return true;
 }
 
 bool Paramount::isSlewComplete()
 {
-    int rc = 0, nbytes_written = 0, nbytes_read = 0, errorCode = 0;
+    int rc = 0, nbytes_written = 0, nbytes_read = 0;
     char pCMD[MAXRBUF] = {0}, pRES[MAXRBUF] = {0};
 
     strncpy(pCMD,
             "/* Java Script */"
             "var Out;"
-            "Out = sky6RASCOMTele.IsSlewComplete;",
+            "Out = sky6RASCOMTele.IsSlewComplete + '#';",
             MAXRBUF);
 
     LOGF_DEBUG("CMD: %s", pCMD);
 
     if ((rc = tty_write_string(PortFD, pCMD, &nbytes_written)) != TTY_OK)
     {
-        LOG_ERROR("Error writing to TheSky6 TCP server.");
+        LOGF_ERROR("Error writing IsSlewComplete to TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
-    // Should we read until we encounter string terminator? or what?
-    if (static_cast<int>(rc == tty_read_section(PortFD, pRES, '\0', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
+    if ((rc = tty_read_section(PortFD, pRES, '#', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
     {
-        LOG_ERROR("Error reading from TheSky6 TCP server.");
+        LOGF_ERROR("Error reading IsSlewComplete from TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
     LOGF_DEBUG("RES: %s", pRES);
 
-    std::regex rgx(R"((.+)|(.+)\. Error = (\d+)\.)");
-    std::smatch match;
-    std::string input(pRES);
-    if (std::regex_search(input, match, rgx))
+    int isComplete = 0;
+    if (sscanf(pRES, "|No error. Error = 0.%d#", &isComplete) == 1)
     {
-        errorCode = atoi(match.str(3).c_str());
-
-        if (errorCode == 0)
-        {
-            int isComplete = atoi(match.str(1).c_str());
-            return (isComplete == 1);
-        }
+        return  isComplete == 1 ? 1 : 0;
     }
 
-    LOGF_ERROR("Error reading isSlewComplete %s (%d).", match.str(2).c_str(), errorCode);
+    LOGF_ERROR("Error reading isSlewComplete. Result: %s", pRES);
     return false;
 }
 
@@ -502,34 +471,29 @@ bool Paramount::isTheSkyParked()
     strncpy(pCMD,
             "/* Java Script */"
             "var Out;"
-            "Out = sky6RASCOMTele.IsParked();",
+            "Out = sky6RASCOMTele.IsParked() + '#';",
             MAXRBUF);
 
     LOGF_DEBUG("CMD: %s", pCMD);
 
     if ((rc = tty_write_string(PortFD, pCMD, &nbytes_written)) != TTY_OK)
     {
-        LOG_ERROR("Error writing to TheSky6 TCP server.");
+        LOGF_ERROR("Error writing sky6RASCOMTele.IsParked() to TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
-    // Should we read until we encounter string terminator? or what?
-    if (static_cast<int>(rc == tty_read_section(PortFD, pRES, '\0', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
+    if ((rc = tty_read_section(PortFD, pRES, '#', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
     {
-        LOG_ERROR("Error reading from TheSky6 TCP server.");
+        LOGF_ERROR("Error reading sky6RASCOMTele.IsParked() from TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
     LOGF_DEBUG("RES: %s", pRES);
 
-    std::regex rgx(R"((.+)\|(.+)\. Error = (\d+)\.)");
-    std::smatch match;
-    std::string input(pRES);
-
-    if (std::regex_search(input, match, rgx))
-    {
-        return strcmp("true", match.str(1).c_str()) == 0;
-    }
+    if (strcmp(pRES, "|No error. Error = 0.true#") == 0)
+        return true;
+    if (strcmp(pRES, "|No error. Error = 0.false#") == 0)
+        return false;
 
     LOGF_ERROR("Error checking for park. Invalid response: %s", pRES);
     return false;
@@ -543,33 +507,32 @@ bool Paramount::isTheSkyTracking()
     strncpy(pCMD,
             "/* Java Script */"
             "var Out;"
-            "Out = sky6RASCOMTele.IsTracking;",
+            "Out = sky6RASCOMTele.IsTracking + '#';",
             MAXRBUF);
 
     LOGF_DEBUG("CMD: %s", pCMD);
 
     if ((rc = tty_write_string(PortFD, pCMD, &nbytes_written)) != TTY_OK)
     {
-        LOG_ERROR("Error writing to TheSky6 TCP server.");
+        LOGF_ERROR("Error writing sky6RASCOMTele.IsTracking to TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
-    // Should we read until we encounter string terminator? or what?
-    if (static_cast<int>(rc == tty_read_section(PortFD, pRES, '\0', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
+    if ((rc = tty_read_section(PortFD, pRES, '#', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
     {
-        LOG_ERROR("Error reading from TheSky6 TCP server.");
+        LOGF_ERROR("Error reading sky6RASCOMTele.IsTracking from TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
     LOGF_DEBUG("RES: %s", pRES);
 
-    std::regex rgx(R"((.+)\|(.+)\. Error = (\d+)\.)");
-    std::smatch match;
-    std::string input(pRES);
-
-    if (std::regex_search(input, match, rgx))
+    double SkyXTrackRate = 0.;
+    if (sscanf(pRES, "|No error. Error = 0.%lf#", &SkyXTrackRate) == 1)
     {
-        return strcmp("1", match.str(1).c_str()) == 0;
+        if (SkyXTrackRate == 0)
+            return false;
+        else if (SkyXTrackRate > 0)
+            return true;
     }
 
     LOGF_ERROR("Error checking for tracking. Invalid response: %s", pRES);
@@ -603,12 +566,16 @@ bool Paramount::Park()
     targetDEC = GetAxis2Park();
 
     char pCMD[MAXRBUF] = {0};
-    strncpy(pCMD, "sky6RASCOMTele.ParkAndDoNotDisconnect();", MAXRBUF);
+    strncpy(pCMD,
+            "sky6RASCOMTele.Asynchronous = true;"
+            "sky6RASCOMTele.ParkAndDoNotDisconnect();",
+            MAXRBUF);
+
     if (!sendTheSkyOKCommand(pCMD, "Parking mount"))
         return false;
-
     TrackState = SCOPE_PARKING;
     LOG_INFO("Parking telescope in progress...");
+
     return true;
 }
 
@@ -619,7 +586,11 @@ bool Paramount::UnPark()
     if (!sendTheSkyOKCommand(pCMD, "Unparking mount"))
         return false;
 
-    SetParked(false);
+    // Confirm we unparked
+    if (isTheSkyParked())
+        LOG_ERROR("Could not unpark for some reason.");
+    else
+        SetParked(false);
 
     return true;
 }
@@ -627,7 +598,6 @@ bool Paramount::UnPark()
 bool Paramount::ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
 {
     //  first check if it's for our device
-
     if (dev != nullptr && strcmp(dev, getDeviceName()) == 0)
     {
         if (strcmp(name, "JOG_RATE") == 0)
@@ -654,8 +624,7 @@ bool Paramount::ISNewNumber(const char *dev, const char *name, double values[],
         }
     }
 
-    //  if we didn't process it, continue up the chain, let somebody else
-    //  give it a shot
+    //  if we didn't process it, continue up the chain, let somebody else give it a shot
     return INDI::Telescope::ISNewNumber(dev, name, values, names, n);
 }
 
@@ -665,17 +634,19 @@ bool Paramount::ISNewSwitch(const char *dev, const char *name, ISState *states,
     {
         if (!strcmp(HomeSP.name, name))
         {
+            LOG_INFO("Moving to home position. Please stand by...");
             if (findHome())
             {
-                HomeS[0].s = ISS_ON;
-                TrackState = SCOPE_SLEWING;
-                HomeSP.s = IPS_BUSY;
-                LOG_INFO("Finding Home position...");
+                HomeS[0].s = ISS_OFF;
+                TrackState = SCOPE_IDLE;
+                HomeSP.s = IPS_OK;
+                LOG_INFO("Mount arrived at home position.");
             }
             else
             {
                 HomeS[0].s = ISS_OFF;
                 HomeSP.s = IPS_ALERT;
+                LOG_ERROR("Failed to go to home position");
             }
 
             IDSetSwitch(&HomeSP, nullptr);
@@ -698,8 +669,11 @@ bool Paramount::findHome()
 {
     char pCMD[MAXRBUF] = {0};
 
-    strncpy(pCMD, "sky6RASCOMTele.FindHome();", MAXRBUF);
-    return sendTheSkyOKCommand(pCMD, "Find home");
+    strncpy(pCMD, "sky6RASCOMTele.FindHome();"
+            "while(!sky6RASCOMTele.IsSlewComplete) {"
+            "sky6Web.Sleep(1000);}",
+            MAXRBUF);
+    return sendTheSkyOKCommand(pCMD, "Find home", 60);
 }
 
 
@@ -796,20 +770,6 @@ bool Paramount::stopOpenLoopMotion()
     return sendTheSkyOKCommand(pCMD, "Stopping open loop motion");
 }
 
-bool Paramount::updateLocation(double latitude, double longitude, double elevation)
-{
-    INDI_UNUSED(elevation);
-    // JM: INDI Longitude is 0 to 360 increasing EAST. libnova East is Positive, West is negative
-    lnobserver.lng = longitude;
-
-    if (lnobserver.lng > 180)
-        lnobserver.lng -= 360;
-    lnobserver.lat = latitude;
-
-    LOGF_INFO("Location updated: Longitude (%g) Latitude (%g)", lnobserver.lng, lnobserver.lat);
-    return true;
-}
-
 bool Paramount::updateTime(ln_date *utc, double utc_offset)
 {
     INDI_UNUSED(utc);
@@ -993,7 +953,7 @@ void Paramount::mountSim()
     NewRaDec(currentRA, currentDEC);
 }
 
-bool Paramount::sendTheSkyOKCommand(const char *command, const char *errorMessage)
+bool Paramount::sendTheSkyOKCommand(const char *command, const char *errorMessage, uint8_t timeout)
 {
     int rc = 0, nbytes_written = 0, nbytes_read = 0;
     char pCMD[MAXRBUF] = {0}, pRES[MAXRBUF] = {0};
@@ -1003,98 +963,105 @@ bool Paramount::sendTheSkyOKCommand(const char *command, const char *errorMessag
              "var Out;"
              "try {"
              "%s"
-             "Out  = 'OK'; }"
+             "Out  = 'OK#'; }"
              "catch (err) {Out = err; }",
              command);
 
     LOGF_DEBUG("CMD: %s", pCMD);
 
+    tcflush(PortFD, TCIOFLUSH);
+
     if ((rc = tty_write_string(PortFD, pCMD, &nbytes_written)) != TTY_OK)
     {
-        LOG_ERROR("Error writing to TheSky6 TCP server.");
+        LOGF_ERROR("Error writing sendTheSkyOKCommand to TheSkyX TCP server. Result: $%d", rc);
         return false;
     }
 
-    if (static_cast<int>(rc == tty_read_section(PortFD, pRES, '\0', PARAMOUNT_TIMEOUT, &nbytes_read)) != TTY_OK)
+    if ((rc = tty_read_section(PortFD, pRES, '#', timeout, &nbytes_read)) != TTY_OK)
     {
-        LOG_ERROR("Error reading from TheSky6 TCP server.");
+        LOGF_ERROR("Error reading sendTheSkyOKCommand from TheSkyX TCP server. Result: %d", rc);
         return false;
     }
 
     LOGF_DEBUG("RES: %s", pRES);
 
-    std::regex rgx(R"((.+)\|(.+)\. Error = (\d+)\.)");
-    std::smatch match;
-    std::string input(pRES);
-    if (std::regex_search(input, match, rgx))
-    {
-        // If NOT OK, then fail
-        if (strcmp("OK", match.str(1).c_str()) != 0)
-        {
-            LOGF_ERROR("Error %s %s", errorMessage, match.str(1).c_str());
-            return false;
-        }
-    }
+    tcflush(PortFD, TCIOFLUSH);
+
+    if (strcmp("|No error. Error = 0.OK#", pRES) == 0 )
+        return true;
     else
     {
-        LOGF_ERROR("Error %s. Invalid response: %s", errorMessage, pRES);
+        LOGF_ERROR("sendTheSkyOKCommand Error %s - Invalid response: %s", errorMessage, pRES);
         return false;
     }
-
-    return true;
 }
 
 IPState Paramount::GuideNorth(uint32_t ms)
 {
-    // Movement in arcseconds
-    double dDec = GuideRateN[DEC_AXIS].value * TRACKRATE_SIDEREAL * ms / 1000.0;
-
-    char pCMD[MAXRBUF] = {0};
-    snprintf(pCMD, MAXRBUF, "sky6DirectGuide.MoveTelescope(%g, %g);", 0., dDec);
-
-    if (!sendTheSkyOKCommand(pCMD, "Guiding north"))
-        return IPS_ALERT;
-
-    return IPS_OK;
+    return GuideNS(static_cast<int>(ms));
 }
 
 IPState Paramount::GuideSouth(uint32_t ms)
 {
-    // Movement in arcseconds
-    double dDec = GuideRateN[DEC_AXIS].value * TRACKRATE_SIDEREAL * ms / -1000.0;
-    char pCMD[MAXRBUF] = {0};
-
-    snprintf(pCMD, MAXRBUF, "sky6DirectGuide.MoveTelescope(%g, %g);", 0., dDec);
-    if (!sendTheSkyOKCommand(pCMD, "Guiding south"))
-        return IPS_ALERT;
-
-    return IPS_OK;
+    return GuideNS(-static_cast<int>(ms));
 }
 
 IPState Paramount::GuideEast(uint32_t ms)
 {
-    // Movement in arcseconds
-    double dRA = GuideRateN[RA_AXIS].value * TRACKRATE_SIDEREAL * ms / 1000.0;
-    char pCMD[MAXRBUF] = {0};
-
-    snprintf(pCMD, MAXRBUF, "sky6DirectGuide.MoveTelescope(%g, %g);", dRA, 0.);
-    if (!sendTheSkyOKCommand(pCMD, "Guiding east"))
-        return IPS_ALERT;
-
-    return IPS_OK;
+    return GuideWE(static_cast<int>(ms));
 }
 
 IPState Paramount::GuideWest(uint32_t ms)
 {
-    // Movement in arcseconds
-    double dRA = GuideRateN[RA_AXIS].value * TRACKRATE_SIDEREAL * ms / -1000.0;
-    char pCMD[MAXRBUF] = {0};
+    return GuideWE(-static_cast<int>(ms));
+}
 
-    snprintf(pCMD, MAXRBUF, "sky6DirectGuide.MoveTelescope(%g, %g);", dRA, 0.);
-    if (!sendTheSkyOKCommand(pCMD, "Guiding west"))
+IPState Paramount::GuideNS(int32_t ms)
+{
+    if (TrackState == SCOPE_PARKED)
+    {
+        LOG_ERROR("Please unpark the mount before issuing any motion commands.");
+        return IPS_ALERT;
+    }
+
+    // Movement in arcseconds
+    // Send async
+    double dDec = GuideRateN[DEC_AXIS].value * TRACKRATE_SIDEREAL * ms / 1000.0;
+    char pCMD[MAXRBUF] = {0};
+    snprintf(pCMD, MAXRBUF,
+             "sky6RASCOMTele.Asynchronous = true;"
+             "sky6DirectGuide.MoveTelescope(%g, %g);", 0., dDec);
+
+    if (!sendTheSkyOKCommand(pCMD, "Guide North-South"))
         return IPS_ALERT;
 
-    return IPS_OK;
+    m_NSTimer.start(ms);
+
+    return IPS_BUSY;
+}
+
+IPState Paramount::GuideWE(int32_t ms)
+{
+    if (TrackState == SCOPE_PARKED)
+    {
+        LOG_ERROR("Please unpark the mount before issuing any motion commands.");
+        return IPS_ALERT;
+    }
+
+    // Movement in arcseconds
+    // Send async
+    double dRA  = GuideRateN[RA_AXIS].value * TRACKRATE_SIDEREAL * ms / 1000.0;
+    char pCMD[MAXRBUF] = {0};
+    snprintf(pCMD, MAXRBUF,
+             "sky6RASCOMTele.Asynchronous = true;"
+             "sky6DirectGuide.MoveTelescope(%g, %g);", dRA, 0.);
+
+    if (!sendTheSkyOKCommand(pCMD, "Guide West-East"))
+        return IPS_ALERT;
+
+    m_WETimer.start(ms);
+
+    return IPS_BUSY;
 }
 
 bool Paramount::setTheSkyTracking(bool enable, bool isSidereal, double raRate, double deRate)
@@ -1115,7 +1082,7 @@ bool Paramount::SetTrackRate(double raRate, double deRate)
 bool Paramount::SetTrackMode(uint8_t mode)
 {
     bool isSidereal = (mode == TRACK_SIDEREAL);
-    double dRA = TRACKRATE_SIDEREAL, dDE = 0;
+    double dRA = 0, dDE = 0;
 
     if (mode == TRACK_SOLAR)
         dRA = TRACKRATE_SOLAR;
@@ -1136,5 +1103,5 @@ bool Paramount::SetTrackEnabled(bool enabled)
         return SetTrackMode(IUFindOnSwitchIndex(&TrackModeSP));
     else
         // Otherwise, simply switch everything off
-        return setTheSkyTracking(false, false, 0, 0);
+        return setTheSkyTracking(0, 0, 0., 0.);
 }
