@@ -187,7 +187,7 @@ bool SynscanLegacyDriver::updateProperties()
     if (isConnected())
     {
         UpdateMountInformation(false);
-        defineText(&BasicMountInfoTP);
+        defineProperty(&BasicMountInfoTP);
     }
     else
     {
@@ -220,7 +220,7 @@ bool SynscanLegacyDriver::AnalyzeMount()
     bool rc = true;
     int tmp = 0;
     int bytesWritten = 0;
-    int bytesRead, numread;
+    int bytesRead;
     char res[MAX_SYN_BUF] = {0};
 
     // JM 2018-08-15 Why are we reading caps here? Looks like it serves no purpose
@@ -315,7 +315,7 @@ bool SynscanLegacyDriver::AnalyzeMount()
         memset(res, 0, MAX_SYN_BUF);
         LOG_DEBUG("CMD <t>");
         tty_write(PortFD, "t", 1, &bytesWritten);
-        numread = tty_read(PortFD, res, 2, 2, &bytesRead);
+        tty_read(PortFD, res, 2, 2, &bytesRead);
         LOGF_DEBUG("RES <%s>", res);
 
         if (res[1] == '#' && static_cast<int>(res[0]) != 0)
@@ -358,7 +358,6 @@ bool SynscanLegacyDriver::ReadScopeStatus()
 
     char res[MAX_SYN_BUF] = {0};
     int bytesWritten, bytesRead;
-    int numread;
     double ra, dec;
     long unsigned int n1, n2;
 
@@ -388,7 +387,6 @@ bool SynscanLegacyDriver::ReadScopeStatus()
 
         if(HasFailed) {
             int v1,v2;
-        //fprintf(stderr,"Calling passthru command to get motor firmware versions\n");
             v1=PassthruCommand(0xfe,0x11,1,0,2);
             v2=PassthruCommand(0xfe,0x10,1,0,2);
             fprintf(stderr,"Motor firmware versions %d %d\n",v1,v2);
@@ -423,7 +421,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
     memset(res, 0, MAX_SYN_BUF);
     LOG_DEBUG("CMD <J>");
     tty_write(PortFD, "J", 1, &bytesWritten);
-    numread = tty_read(PortFD, res, 2, 2, &bytesRead);
+    tty_read(PortFD, res, 2, 2, &bytesRead);
     LOGF_DEBUG("RES <%s>", res);
     if (res[1] == '#')
     {
@@ -432,7 +430,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
     memset(res, 0, MAX_SYN_BUF);
     LOG_DEBUG("CMD <L>");
     tty_write(PortFD, "L", 1, &bytesWritten);
-    numread = tty_read(PortFD, res, 2, 2, &bytesRead);
+    tty_read(PortFD, res, 2, 2, &bytesRead);
     LOGF_DEBUG("RES <%s>", res);
     if (res[1] == '#')
     {
@@ -441,7 +439,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
     memset(res, 0, MAX_SYN_BUF);
     LOG_DEBUG("CMD <p>");
     tty_write(PortFD, "p", 1, &bytesWritten);
-    numread = tty_read(PortFD, res, 2, 2, &bytesRead);
+    tty_read(PortFD, res, 2, 2, &bytesRead);
     LOGF_DEBUG("RES <%s>", res);
     if (res[1] == '#')
     {
@@ -453,7 +451,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
     memset(res, 0, MAX_SYN_BUF);
     LOG_DEBUG("CMD <t>");
     tty_write(PortFD, "t", 1, &bytesWritten);
-    numread = tty_read(PortFD, res, 2, 2, &bytesRead);
+    tty_read(PortFD, res, 2, 2, &bytesRead);
     LOGF_DEBUG("RES <%s>", res);
     if (res[1] == '#')
     {
@@ -504,7 +502,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
             memset(res, 0, 3);
             LOG_DEBUG("CMD <L>");
             tty_write(PortFD, "L", 1, &bytesWritten);
-            numread = tty_read(PortFD, res, 2, 3, &bytesRead);
+            tty_read(PortFD, res, 2, 3, &bytesRead);
             LOGF_DEBUG("RES <%s>", res);
             if (res[0] != 48)
             {
@@ -533,7 +531,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
             memset(res, 0, MAX_SYN_BUF);
             LOG_DEBUG("CMD <z>");
             tty_write(PortFD, "z", 1, &bytesWritten);
-            numread = tty_read(PortFD, res, 18, 2, &bytesRead);
+            tty_read(PortFD, res, 18, 2, &bytesRead);
             LOGF_DEBUG("RES <%s>", res);
 
             //IDMessage(getDeviceName(),"Park Read %s %d",res,StopCount);
@@ -576,7 +574,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
     memset(res, 0, MAX_SYN_BUF);
     LOG_DEBUG("CMD <e>");
     tty_write(PortFD, "e", 1, &bytesWritten);
-    numread = tty_read(PortFD, res, 18, 1, &bytesRead);
+    tty_read(PortFD, res, 18, 1, &bytesRead);
     LOGF_DEBUG("RES <%s>", res);
     if (bytesRead != 18)
     {
@@ -588,28 +586,27 @@ bool SynscanLegacyDriver::ReadScopeStatus()
     ra  = static_cast<double>(n1) / 0x100000000 * 24.0;
     dec = static_cast<double>(n2) / 0x100000000 * 360.0;
 
-    ln_equ_posn epochPos { 0, 0 }, J2000Pos { 0, 0 };
-    J2000Pos.ra  = range24(ra) * 15.0;
-    J2000Pos.dec = rangeDec(dec);
+    INDI::IEquatorialCoordinates epochPos { 0, 0 }, J2000Pos { 0, 0 };
+    J2000Pos.rightascension  = range24(ra);
+    J2000Pos.declination = rangeDec(dec);
 
     // Synscan reports J2000 coordinates so we need to convert from J2000 to JNow
-    //ln_get_equ_prec2(&J2000Pos, JD2000, ln_get_julian_from_sys(), &epochPos);
-    LibAstro::J2000toObserved(&J2000Pos, ln_get_julian_from_sys(), &epochPos);
+    INDI::J2000toObserved(&J2000Pos, ln_get_julian_from_sys(), &epochPos);
 
-    CurrentRA  = epochPos.ra / 15.0;
-    CurrentDEC = epochPos.dec;
+    CurrentRA  = epochPos.rightascension;
+    CurrentDEC = epochPos.declination;
 
     //  Now feed the rest of the system with corrected data
     NewRaDec(CurrentRA, CurrentDEC);
 
     if (TrackState == SCOPE_SLEWING && MountCode >= 128 && (SlewTargetAz != -1 || SlewTargetAlt != -1))
     {
-        ln_hrz_posn CurrentAltAz { 0, 0 };
+        INDI::IHorizontalCoordinates CurrentAltAz { 0, 0 };
         double DiffAlt { 0 };
         double DiffAz { 0 };
 
-        CurrentAltAz = GetAltAzPosition(ra, dec);
-        DiffAlt = CurrentAltAz.alt - SlewTargetAlt;
+        INDI::EquatorialToHorizontal(&epochPos, &m_Location, ln_get_julian_from_sys(), &CurrentAltAz);
+        DiffAlt = CurrentAltAz.altitude - SlewTargetAlt;
         if (SlewTargetAlt != -1 && std::abs(DiffAlt) > 0.01)
         {
             int NewRate = 2;
@@ -635,7 +632,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
                 NewRate = 3;
             }
             LOGF_DEBUG("Slewing Alt axis: %1.3f-%1.3f -> %1.3f (speed: %d)",
-                       CurrentAltAz.alt, SlewTargetAlt, CurrentAltAz.alt - SlewTargetAlt, CustomNSSlewRate);
+                       CurrentAltAz.altitude, SlewTargetAlt, CurrentAltAz.altitude - SlewTargetAlt, CustomNSSlewRate);
             if (NewRate != CustomNSSlewRate)
             {
                 if (DiffAlt < 0)
@@ -656,7 +653,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
             SlewTargetAlt = -1;
             LOG_DEBUG("Slewing on Alt axis finished");
         }
-        DiffAz = CurrentAltAz.az - SlewTargetAz;
+        DiffAz = CurrentAltAz.azimuth - SlewTargetAz;
         if (DiffAz < -180)
             DiffAz = (DiffAz + 360) * 2;
         else if (DiffAz > 180)
@@ -686,7 +683,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
                 NewRate = 3;
             }
             LOGF_DEBUG("Slewing Az axis: %1.3f-%1.3f -> %1.3f (speed: %d)",
-                       CurrentAltAz.az, SlewTargetAz, CurrentAltAz.az - SlewTargetAz, CustomWESlewRate);
+                       CurrentAltAz.azimuth, SlewTargetAz, CurrentAltAz.azimuth - SlewTargetAz, CustomWESlewRate);
             if (NewRate != CustomWESlewRate)
             {
                 if (DiffAz > 0)
@@ -718,7 +715,7 @@ bool SynscanLegacyDriver::ReadScopeStatus()
 bool SynscanLegacyDriver::StartTrackMode()
 {
     char res[MAX_SYN_BUF] = {0};
-    int numread, bytesWritten, bytesRead;
+    int bytesWritten, bytesRead;
 
     TrackState = SCOPE_TRACKING;
     LOG_INFO("Tracking started.");
@@ -740,7 +737,7 @@ bool SynscanLegacyDriver::StartTrackMode()
         res[1] = 2;
     }
     tty_write(PortFD, res, 2, &bytesWritten);
-    numread = tty_read(PortFD, res, 1, 2, &bytesRead);
+    tty_read(PortFD, res, 1, 2, &bytesRead);
     if (bytesRead != 1 || res[0] != '#')
     {
         LOG_DEBUG("Timeout waiting for scope to start tracking.");
@@ -753,7 +750,7 @@ bool SynscanLegacyDriver::Goto(double ra, double dec)
 {
     char res[MAX_SYN_BUF] = {0};
     int bytesWritten, bytesRead;
-    ln_hrz_posn TargetAltAz { 0, 0 };
+    INDI::IHorizontalCoordinates TargetAltAz { 0, 0 };
 
     if (isSimulation() == false)
     {
@@ -774,21 +771,19 @@ bool SynscanLegacyDriver::Goto(double ra, double dec)
     // EQ mount has a different Goto mode
     if (MountCode < 128 && isSimulation() == false)
     {
-        ln_equ_posn epochPos { 0, 0 }, J2000Pos { 0, 0 };
-
-        epochPos.ra  = ra * 15.0;
-        epochPos.dec = dec;
+        INDI::IEquatorialCoordinates epochPos { 0, 0 }, J2000Pos { 0, 0 };
+        epochPos.rightascension  = ra;
+        epochPos.declination = dec;
 
         // Synscan accepts J2000 coordinates so we need to convert from JNow to J2000
-        //ln_get_equ_prec2(&epochPos, ln_get_julian_from_sys(), JD2000, &J2000Pos);
-        LibAstro::ObservedToJ2000(&epochPos, ln_get_julian_from_sys(), &J2000Pos);
+        INDI::ObservedToJ2000(&epochPos, ln_get_julian_from_sys(), &J2000Pos);
 
         // Mount deals in J2000 coords.
-        int n1 = J2000Pos.ra / 15.0 * 0x1000000 / 24;
-        int n2 = J2000Pos.dec * 0x1000000 / 360;
-        int numread;
+        int n1 = J2000Pos.rightascension * 0x1000000 / 24;
+        int n2 = J2000Pos.declination * 0x1000000 / 360;
 
-        LOGF_DEBUG("Goto - JNow RA: %g JNow DE: %g J2000 RA: %g J2000 DE: %g", ra, dec, J2000Pos.ra / 15.0, J2000Pos.dec);
+        LOGF_DEBUG("Goto - JNow RA: %g JNow DE: %g J2000 RA: %g J2000 DE: %g", ra, dec, J2000Pos.rightascension,
+                   J2000Pos.declination);
 
         n1 = n1 << 8;
         n2 = n2 << 8;
@@ -797,7 +792,7 @@ bool SynscanLegacyDriver::Goto(double ra, double dec)
         tty_write(PortFD, res, 18, &bytesWritten);
         memset(&res[18], 0, 1);
 
-        numread = tty_read(PortFD, res, 1, 60, &bytesRead);
+        tty_read(PortFD, res, 1, 60, &bytesRead);
         if (bytesRead != 1 || res[0] != '#')
         {
             LOG_DEBUG("Timeout waiting for scope to complete goto.");
@@ -807,18 +802,19 @@ bool SynscanLegacyDriver::Goto(double ra, double dec)
         return true;
     }
 
-    TargetAltAz = GetAltAzPosition(ra, dec);
-    LOGF_DEBUG("Goto - JNow RA: %g JNow DE: %g (az: %g alt: %g)", ra, dec, TargetAltAz.az, TargetAltAz.alt);
+    INDI::IEquatorialCoordinates epochPos { ra, dec };
+    INDI::EquatorialToHorizontal(&epochPos, &m_Location, ln_get_julian_from_sys(), &TargetAltAz);
+    LOGF_DEBUG("Goto - JNow RA: %g JNow DE: %g (az: %g alt: %g)", ra, dec, TargetAltAz.azimuth, TargetAltAz.altitude);
     char RAStr[MAX_SYN_BUF] = {0}, DEStr[MAX_SYN_BUF] = {0}, AZStr[MAX_SYN_BUF] = {0}, ATStr[MAX_SYN_BUF] = {0};
     fs_sexa(RAStr, ra, 2, 3600);
     fs_sexa(DEStr, dec, 2, 3600);
-    fs_sexa(AZStr, TargetAltAz.az, 2, 3600);
-    fs_sexa(ATStr, TargetAltAz.alt, 2, 3600);
+    fs_sexa(AZStr, TargetAltAz.azimuth, 2, 3600);
+    fs_sexa(ATStr, TargetAltAz.altitude, 2, 3600);
 
     LOGF_INFO("Goto RA: %s DE: %s AZ: %s ALT: %s", RAStr, DEStr, AZStr, ATStr);
 
-    SlewTargetAz = TargetAltAz.az;
-    SlewTargetAlt = TargetAltAz.alt;
+    SlewTargetAz = TargetAltAz.azimuth;
+    SlewTargetAlt = TargetAltAz.altitude;
 
     TargetRA = ra;
     TargetDEC = dec;
@@ -829,7 +825,7 @@ bool SynscanLegacyDriver::Goto(double ra, double dec)
 bool SynscanLegacyDriver::Park()
 {
     char res[MAX_SYN_BUF] = {0};
-    int numread, bytesWritten, bytesRead;
+    int bytesWritten, bytesRead;
 
     if (isSimulation() == false)
     {
@@ -847,7 +843,7 @@ bool SynscanLegacyDriver::Park()
         res[0] = 'T';
         res[1] = 0;
         tty_write(PortFD, res, 2, &bytesWritten);
-        numread = tty_read(PortFD, res, 1, 60, &bytesRead);
+        tty_read(PortFD, res, 1, 60, &bytesRead);
         if (bytesRead != 1 || res[0] != '#')
         {
             LOG_DEBUG("Timeout waiting for scope to stop tracking.");
@@ -856,7 +852,7 @@ bool SynscanLegacyDriver::Park()
 
         //sprintf((char *)res,"b%08X,%08X",0x0,0x40000000);
         tty_write(PortFD, "b00000000,40000000", 18, &bytesWritten);
-        numread = tty_read(PortFD, res, 1, 60, &bytesRead);
+        tty_read(PortFD, res, 1, 60, &bytesRead);
         if (bytesRead != 1 || res[0] != '#')
         {
             LOG_DEBUG("Timeout waiting for scope to respond to park.");
@@ -902,7 +898,7 @@ bool SynscanLegacyDriver::Abort()
         return true;
 
     char res[MAX_SYN_BUF] = {0};
-    int numread, bytesWritten, bytesRead;
+    int bytesWritten, bytesRead;
 
     LOG_DEBUG("Abort mount...");
     TrackState = SCOPE_IDLE;
@@ -921,7 +917,7 @@ bool SynscanLegacyDriver::Abort()
     LOGF_DEBUG("CMD <%s>", res);
     tty_write(PortFD, res, 2, &bytesWritten);
 
-    numread = tty_read(PortFD, res, 1, 2, &bytesRead);
+    tty_read(PortFD, res, 1, 2, &bytesRead);
     LOGF_DEBUG("RES <%s>", res);
 
     if (bytesRead != 1 || res[0] != '#')
@@ -1285,10 +1281,6 @@ bool SynscanLegacyDriver::updateLocation(double latitude, double longitude, doub
     ln_lnlat_posn p1 { 0, 0 };
     lnh_lnlat_posn p2;
 
-    LocationN[LOCATION_LATITUDE].value  = latitude;
-    LocationN[LOCATION_LONGITUDE].value = longitude;
-    IDSetNumber(&LocationNP, nullptr);
-
     if (isSimulation())
     {
         if (CurrentDEC == 0)
@@ -1391,7 +1383,7 @@ bool SynscanLegacyDriver::Sync(double ra, double dec)
 
     LOGF_INFO("Sync JNow %g %g -> %g %g", CurrentRA, CurrentDEC, ra, dec);
     char res[MAX_SYN_BUF] = {0};
-    int numread, bytesWritten, bytesRead;
+    int bytesWritten, bytesRead;
 
     if (isSimulation())
     {
@@ -1403,12 +1395,12 @@ bool SynscanLegacyDriver::Sync(double ra, double dec)
     // Alt/Az sync mode
     if (MountCode >= 128)
     {
-        ln_hrz_posn TargetAltAz { 0, 0 };
-
-        TargetAltAz = GetAltAzPosition(ra, dec);
-        LOGF_DEBUG("Sync - ra: %g de: %g to az: %g alt: %g", ra, dec, TargetAltAz.az, TargetAltAz.alt);
+        INDI::IHorizontalCoordinates TargetAltAz { 0, 0 };
+        INDI::IEquatorialCoordinates epochPos {ra, dec};
+        INDI::EquatorialToHorizontal(&epochPos, &m_Location, ln_get_julian_from_sys(), &TargetAltAz);
+        LOGF_DEBUG("Sync - ra: %g de: %g to az: %g alt: %g", ra, dec, TargetAltAz.azimuth, TargetAltAz.altitude);
         // Assemble the Reset Position command for Az axis
-        int Az = (int)(TargetAltAz.az * 16777216 / 360);
+        int Az = (int)(TargetAltAz.azimuth * 16777216 / 360);
 
         res[0] = 'P';
         res[1] = 4;
@@ -1421,9 +1413,9 @@ bool SynscanLegacyDriver::Sync(double ra, double dec)
         *reinterpret_cast<unsigned char*>(&res[6]) = (unsigned char)Az;
         res[7] = 0;
         tty_write(PortFD, res, 8, &bytesWritten);
-        numread = tty_read(PortFD, res, 1, 3, &bytesRead);
+        tty_read(PortFD, res, 1, 3, &bytesRead);
         // Assemble the Reset Position command for Alt axis
-        int Alt = (int)(TargetAltAz.alt * 16777216 / 360);
+        int Alt = (int)(TargetAltAz.altitude * 16777216 / 360);
 
         res[0] = 'P';
         res[1] = 4;
@@ -1438,22 +1430,22 @@ bool SynscanLegacyDriver::Sync(double ra, double dec)
         LOGF_DEBUG("CMD <%s>", res);
         tty_write(PortFD, res, 8, &bytesWritten);
 
-        numread = tty_read(PortFD, res, 1, 2, &bytesRead);
+        tty_read(PortFD, res, 1, 2, &bytesRead);
         LOGF_DEBUG("CMD <%c>", res[0]);
     }
 
-    ln_equ_posn epochPos { 0, 0 }, J2000Pos { 0, 0 };
+    INDI::IEquatorialCoordinates epochPos { 0, 0 }, J2000Pos { 0, 0 };
 
-    epochPos.ra  = ra * 15.0;
-    epochPos.dec = dec;
+    epochPos.rightascension  = ra;
+    epochPos.declination = dec;
 
     // Synscan accepts J2000 coordinates so we need to convert from JNow to J2000
     //ln_get_equ_prec2(&epochPos, ln_get_julian_from_sys(), JD2000, &J2000Pos);
-    LibAstro::ObservedToJ2000(&epochPos, ln_get_julian_from_sys(), &J2000Pos);
+    INDI::ObservedToJ2000(&epochPos, ln_get_julian_from_sys(), &J2000Pos);
 
     // Pass the sync command to the handset
-    int n1 = J2000Pos.ra / 15.0 * 0x1000000 / 24;
-    int n2 = J2000Pos.dec * 0x1000000 / 360;
+    int n1 = J2000Pos.rightascension * 0x1000000 / 24;
+    int n2 = J2000Pos.declination * 0x1000000 / 360;
 
     n1 = n1 << 8;
     n2 = n2 << 8;
@@ -1463,7 +1455,7 @@ bool SynscanLegacyDriver::Sync(double ra, double dec)
     LOGF_DEBUG("CMD <%s>", res);
     tty_write(PortFD, res, 18, &bytesWritten);
 
-    numread = tty_read(PortFD, res, 1, 60, &bytesRead);
+    tty_read(PortFD, res, 1, 60, &bytesRead);
     LOGF_DEBUG("RES <%c>", res[0]);
 
     if (bytesRead != 1 || res[0] != '#')
@@ -1479,22 +1471,6 @@ bool SynscanLegacyDriver::Sync(double ra, double dec)
     return true;
 }
 
-ln_hrz_posn SynscanLegacyDriver::GetAltAzPosition(double ra, double dec)
-{
-    ln_lnlat_posn Location { 0, 0 };
-    ln_equ_posn Eq { 0, 0 };
-    ln_hrz_posn AltAz { 0, 0 };
-
-    // Set the current location
-    Location.lat = LocationN[LOCATION_LATITUDE].value;
-    Location.lng = LocationN[LOCATION_LONGITUDE].value;
-
-    Eq.ra  = ra * 360.0 / 24.0;
-    Eq.dec = dec;
-    get_hrz_from_equ(&Eq, &Location, ln_get_julian_from_sys(), &AltAz);
-    return AltAz;
-}
-
 void SynscanLegacyDriver::UpdateMountInformation(bool inform_client)
 {
     bool BasicMountInfoHasChanged = false;
