@@ -28,9 +28,11 @@
 #include <cstring>
 #include <curl/curl.h>
 
-#include "gason.h"
+#include "json.h"
 #include "weather_safety_proxy.h"
 
+using json = nlohmann::json;
+
 std::unique_ptr<WeatherSafetyProxy> weatherSafetyProxy(new WeatherSafetyProxy());
 
 static size_t WSP_WriteCallback(void *contents, size_t size, size_t nmemb, void *userp)
@@ -70,25 +72,32 @@ bool WeatherSafetyProxy::initProperties()
     IUFillText(&keywordT[0], "WEATHER_CONDITION", "Weather Condition", "condition");
     IUFillTextVector(&keywordTP, keywordT, 1, getDeviceName(), "KEYWORD", "Keywords", OPTIONS_TAB, IP_RW, 60, IPS_IDLE);
 
-    IUFillText(&ScriptsT[WSP_SCRIPT], "WEATHER_SAFETY_SCRIPT", "Weather safety script", "/usr/local/share/indi/scripts/weather_status.py");
-    IUFillTextVector(&ScriptsTP, ScriptsT, WSP_SCRIPT_COUNT, getDefaultName(), "WEATHER_SAFETY_SCRIPTS", "Script", OPTIONS_TAB, IP_RW, 100, IPS_IDLE);
+    IUFillText(&ScriptsT[WSP_SCRIPT], "WEATHER_SAFETY_SCRIPT", "Weather safety script",
+               "/usr/local/share/indi/scripts/weather_status.py");
+    IUFillTextVector(&ScriptsTP, ScriptsT, WSP_SCRIPT_COUNT, getDefaultName(), "WEATHER_SAFETY_SCRIPTS", "Script", OPTIONS_TAB,
+                     IP_RW, 100, IPS_IDLE);
 
     IUFillText(&UrlT[WSP_URL], "WEATHER_SAFETY_URL", "Weather safety URL", "http://0.0.0.0:5000/weather/safety");
-    IUFillTextVector(&UrlTP, UrlT, WSP_URL_COUNT, getDefaultName(), "WEATHER_SAFETY_URLS", "Url", OPTIONS_TAB, IP_RW, 100, IPS_IDLE);
+    IUFillTextVector(&UrlTP, UrlT, WSP_URL_COUNT, getDefaultName(), "WEATHER_SAFETY_URLS", "Url", OPTIONS_TAB, IP_RW, 100,
+                     IPS_IDLE);
 
     IUFillSwitch(&ScriptOrCurlS[WSP_USE_SCRIPT], "Use script", "", ISS_ON);
     IUFillSwitch(&ScriptOrCurlS[WSP_USE_CURL], "Use url", "", ISS_OFF);
-    IUFillSwitchVector(&ScriptOrCurlSP, ScriptOrCurlS, WSP_USE_COUNT, getDeviceName(), "SCRIPT_OR_CURL", "Script or url", OPTIONS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+    IUFillSwitchVector(&ScriptOrCurlSP, ScriptOrCurlS, WSP_USE_COUNT, getDeviceName(), "SCRIPT_OR_CURL", "Script or url",
+                       OPTIONS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
     IUFillNumber(&softErrorHysteresisN[WSP_SOFT_ERROR_MAX], "SOFT_ERROR_MAX", "Max soft errors", "%g", 0.0, 1000.0, 1.0, 30.0);
-    IUFillNumber(&softErrorHysteresisN[WSP_SOFT_ERROR_RECOVERY], "SOFT_ERROR_RECOVERY", "Minimum soft error for recovery", "%g", 0.0, 1000.0, 1.0, 7.0);
-    IUFillNumberVector(&softErrorHysteresisNP, softErrorHysteresisN, 2, getDeviceName(), "SOFT_ERROR_HYSTERESIS", "Soft error hysterese", OPTIONS_TAB, IP_RW, 0, IPS_IDLE);
+    IUFillNumber(&softErrorHysteresisN[WSP_SOFT_ERROR_RECOVERY], "SOFT_ERROR_RECOVERY", "Minimum soft error for recovery", "%g",
+                 0.0, 1000.0, 1.0, 7.0);
+    IUFillNumberVector(&softErrorHysteresisNP, softErrorHysteresisN, 2, getDeviceName(), "SOFT_ERROR_HYSTERESIS",
+                       "Soft error hysterese", OPTIONS_TAB, IP_RW, 0, IPS_IDLE);
 
     addParameter("WEATHER_SAFETY", "Weather Safety", 0.9, 1.1, 0); // 0 is unsafe, 1 is safe
     setCriticalParameter("WEATHER_SAFETY");
 
     IUFillText(&reasonsT[0], "Reasons", "", nullptr);
-    IUFillTextVector(&reasonsTP, reasonsT, 1, getDeviceName(), "WEATHER_SAFETY_REASONS", "Weather Safety Reasons", MAIN_CONTROL_TAB, IP_RO, 120, IPS_IDLE);
+    IUFillTextVector(&reasonsTP, reasonsT, 1, getDeviceName(), "WEATHER_SAFETY_REASONS", "Weather Safety Reasons",
+                     MAIN_CONTROL_TAB, IP_RO, 120, IPS_IDLE);
 
     addDebugControl();
 
@@ -145,7 +154,6 @@ bool WeatherSafetyProxy::ISNewNumber(const char *dev, const char *name, double v
     {
         if (strcmp(name, softErrorHysteresisNP.name) == 0)
         {
-            LOG_DEBUG("WeatherSafetyProxy::ISNewNumber");
             IUUpdateNumber(&softErrorHysteresisNP, values, names, n);
             softErrorHysteresisNP.s = IPS_OK;
             IDSetNumber(&softErrorHysteresisNP, nullptr);
@@ -254,7 +262,7 @@ IPState WeatherSafetyProxy::executeScript()
 {
     const char *cmd = ScriptsT[WSP_SCRIPT].text;
 
-    if (access(cmd, F_OK|X_OK) == -1)
+    if (access(cmd, F_OK | X_OK) == -1)
     {
         LOGF_ERROR("Cannot use script [%s], check its existence and permissions", cmd);
         LastParseSuccess = false;
@@ -281,7 +289,7 @@ IPState WeatherSafetyProxy::executeScript()
     }
     LOGF_DEBUG("Read %d bytes output [%s]", byte_count, buf);
 
-    return parseSafetyJSON(buf, byte_count);
+    return parseSafetyJSON(buf);
 }
 
 IPState WeatherSafetyProxy::executeCurl()
@@ -306,7 +314,7 @@ IPState WeatherSafetyProxy::executeCurl()
         }
         curl_easy_cleanup(curl_handle);
         LOGF_DEBUG("Read %d bytes output [%s]", readBuffer.size(), readBuffer.c_str());
-        return parseSafetyJSON(readBuffer.c_str(), readBuffer.size());
+        return parseSafetyJSON(readBuffer);
     }
     else
     {
@@ -315,122 +323,72 @@ IPState WeatherSafetyProxy::executeCurl()
     }
 }
 
-IPState WeatherSafetyProxy::parseSafetyJSON(const char *clean_buf, int byte_count)
+IPState WeatherSafetyProxy::parseSafetyJSON(const std::string &buffer)
 {
-    // copy clean_buf to buf which jsonParse can destroy
-    char buf[BUFSIZ];
-    strncpy(buf, clean_buf, byte_count);
-
-    char *source = buf;
-    char *endptr;
-    JsonValue value;
-    JsonAllocator allocator;
-    int status = jsonParse(source, &endptr, &value, allocator);
-    if (status != JSON_OK)
+    json report = json::parse(buffer);
+    try
     {
-        LOGF_ERROR("jsonParse %s at position %zd", jsonStrError(status), endptr - source);
-        LastParseSuccess = false;
-        return IPS_ALERT;
-    }
+        int NewSafety = 0;
+        report["roof_status"]["open_ok"].get_to(NewSafety);
 
-    JsonIterator it;
-    JsonIterator observationIterator;
-    bool roof_status_found = false;
-    bool open_ok_found = false;
-    bool reasons_found = false;
-    bool error_found = false;
-    for (it = begin(value); it != end(value); ++it)
-    {
-        if (!strcmp(it->key, "roof_status"))
+        if (NewSafety != Safety)
         {
-            roof_status_found = true;
-            for (observationIterator = begin(it->value); observationIterator != end(it->value); ++observationIterator)
+            if (NewSafety == WSP_UNSAFE)
             {
-                if (!strcmp(observationIterator->key, "open_ok"))
+                LOG_WARN("Weather is UNSAFE");
+            }
+            else if (NewSafety == WSP_SAFE)
+            {
+                if (SofterrorRecoveryMode == true)
                 {
-                    open_ok_found = true;
-                    int NewSafety = observationIterator->value.toNumber();
-                    if (NewSafety != Safety)
+                    SofterrorRecoveryCount++;
+                    if (SofterrorRecoveryCount > softErrorHysteresisN[WSP_SOFT_ERROR_RECOVERY].value)
                     {
-                        if (NewSafety == WSP_UNSAFE)
-                        {
-                            LOG_WARN("Weather is UNSAFE");
-                        }
-                        else if (NewSafety == WSP_SAFE)
-                        {
-                            if (SofterrorRecoveryMode == true)
-                            {
-                                SofterrorRecoveryCount++;
-                                if (SofterrorRecoveryCount > softErrorHysteresisN[WSP_SOFT_ERROR_RECOVERY].value)
-                                {
-                                    LOG_INFO("Minimum soft recovery errors reached while Weather was SAFE");
-                                    SofterrorRecoveryCount = 0;
-                                    SofterrorRecoveryMode = false;
-                                }
-                                else
-                                {
-                                    LOGF_INFO("Weather is SAFE but soft error recovery %d is still counting", SofterrorRecoveryCount);
-                                    NewSafety = WSP_UNSAFE;
-                                }
-                            }
-                            else
-                            {
-                                LOG_INFO("Weather is SAFE");
-                            }
-                        }
-                        Safety = NewSafety;
-                    }
-                    setParameterValue("WEATHER_SAFETY", NewSafety);
-                }
-                else if (!strcmp(observationIterator->key, "reasons"))
-                {
-                    reasons_found = true;
-                    char *reasons = observationIterator->value.toString();
-                    if (SofterrorRecoveryMode == true)
-                    {
-                        char newReasons[MAXRBUF];
-                        snprintf(newReasons, MAXRBUF, "SofterrorRecoveryMode, %s", reasons);
-                        IUSaveText(&reasonsT[0], newReasons);
+                        LOG_INFO("Minimum soft recovery errors reached while Weather was SAFE");
+                        SofterrorRecoveryCount = 0;
+                        SofterrorRecoveryMode = false;
                     }
                     else
                     {
-                        IUSaveText(&reasonsT[0], reasons);
+                        LOGF_INFO("Weather is SAFE but soft error recovery %d is still counting", SofterrorRecoveryCount);
+                        NewSafety = WSP_UNSAFE;
                     }
-                    reasonsTP.s = IPS_OK;
-                    IDSetText(&reasonsTP, nullptr);
+                }
+                else
+                {
+                    LOG_INFO("Weather is SAFE");
                 }
             }
+            Safety = NewSafety;
         }
-        if (!strcmp(it->key, "error"))
+        setParameterValue("WEATHER_SAFETY", NewSafety);
+
+        // Optional reasons?
+        try
         {
-            error_found = true;
+            std::string reasons;
+            report["roof_status"]["reasons"].get_to(reasons);
+            if (SofterrorRecoveryMode == true)
+            {
+                char newReasons[MAXRBUF];
+                snprintf(newReasons, MAXRBUF, "SofterrorRecoveryMode, %s", reasons.c_str());
+                IUSaveText(&reasonsT[0], newReasons);
+            }
+            else
+            {
+                IUSaveText(&reasonsT[0], reasons.c_str());
+            }
+            reasonsTP.s = IPS_OK;
+            IDSetText(&reasonsTP, nullptr);
         }
+        catch (json::exception &e) {}
+    }
+    catch (json::exception &e)
+    {
+        // output exception information
+        LOGF_ERROR("Error parsing weather report %s id: %d", e.what(), e.id);
+        return IPS_ALERT;
     }
 
-    if (error_found)
-    {
-        LOGF_ERROR("Error hint found in JSON [%s]", clean_buf);
-        LastParseSuccess = false;
-        return IPS_ALERT;
-    }
-    if (!roof_status_found)
-    {
-        LOGF_ERROR("Found no roof_status field in JSON [%s]", clean_buf);
-        LastParseSuccess = false;
-        return IPS_ALERT;
-    }
-    if (!open_ok_found)
-    {
-        LOGF_ERROR("Found no open_ok field in roof_status JSON [%s]", clean_buf);
-        LastParseSuccess = false;
-        return IPS_ALERT;
-    }
-    // do not error if reasons are missing, they're not required for safety
-    if (!LastParseSuccess)
-    {
-        // show the good news. Once.
-        LOGF_INFO("Script output fully parsed, weather is %s", (Safety == 1) ? "SAFE" : "UNSAFE");
-        LastParseSuccess = true;
-    }
     return IPS_OK;
 }
