@@ -39,43 +39,6 @@ static size_t write_data(void *contents, size_t size, size_t nmemb, void *userp)
     return size * nmemb;
 }
 
-void ISGetProperties(const char *dev)
-{
-    weatherWatcher->ISGetProperties(dev);
-}
-
-void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n)
-{
-    weatherWatcher->ISNewSwitch(dev, name, states, names, n);
-}
-
-void ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n)
-{
-    weatherWatcher->ISNewText(dev, name, texts, names, n);
-}
-
-void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n)
-{
-    weatherWatcher->ISNewNumber(dev, name, values, names, n);
-}
-
-void ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int n)
-{
-    INDI_UNUSED(dev);
-    INDI_UNUSED(name);
-    INDI_UNUSED(sizes);
-    INDI_UNUSED(blobsizes);
-    INDI_UNUSED(blobs);
-    INDI_UNUSED(formats);
-    INDI_UNUSED(names);
-    INDI_UNUSED(n);
-}
-void ISSnoopDevice(XMLEle *root)
-{
-    weatherWatcher->ISSnoopDevice(root);
-}
-
 WeatherWatcher::WeatherWatcher()
 {
     setVersion(1, 2);
@@ -250,13 +213,13 @@ void WeatherWatcher::ISGetProperties(const char *dev)
 {
     INDI::Weather::ISGetProperties(dev);
 
-    defineText(&watchFileTP);
+    defineProperty(&watchFileTP);
     loadConfig(true, "WATCH_SOURCE");
 
-    defineText(&keywordTP);
+    defineProperty(&keywordTP);
     loadConfig(true, "KEYWORD");
 
-    defineText(&separatorTP);
+    defineProperty(&separatorTP);
     loadConfig(true, "SEPARATOR_KEYWORD");
 
 }
