@@ -20,26 +20,24 @@
 
 #pragma once
 
-#include "defaultdevice.h"
+#include <defaultdevice.h>
+#include <indipropertylight.h>
+#include <indipropertyswitch.h>
 
 class RainDetector : public INDI::DefaultDevice
 {
-public:
-    RainDetector() = default;
+    public:
+        RainDetector() = default;
 
-protected:
-    // General device functions
-    bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n) override;
-    bool Connect() override;
-    bool Disconnect() override;
-    const char *getDefaultName() override;
-    bool initProperties() override;
-    bool updateProperties() override;
+    protected:
+        // General device functions
+        bool Connect() override;
+        bool Disconnect() override;
+        const char *getDefaultName() override;
+        bool initProperties() override;
+        bool updateProperties() override;
 
-private:
-    ILight RainL[1];
-    ILightVectorProperty RainLP;
-
-    ISwitch RainS[2];
-    ISwitchVectorProperty RainSP;
+    private:
+        INDI::PropertyLight  mRainLight  {1};
+        INDI::PropertySwitch mRainSwitch {2};
 };
