@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "basedevice.h"
+#include "parentdevice.h"
 #include "indidriver.h"
 #include "indilogger.h"
 
@@ -115,7 +115,7 @@ namespace INDI
 {
 
 class DefaultDevicePrivate;
-class DefaultDevice : public BaseDevice
+class DefaultDevice : public ParentDevice
 {
         DECLARE_PRIVATE(DefaultDevice)
 
@@ -195,6 +195,14 @@ class DefaultDevice : public BaseDevice
          */
         virtual bool deleteProperty(const char *propertyName);
 
+        /**
+         * @brief deleteProperty Delete a property and unregister it. It will also be deleted from all clients.
+         * @param property Property to be deleted.
+         * @return True if successful, false otherwise.
+         * @note This is a convience function that internally calls deleteProperty with the property name.
+         */
+        bool deleteProperty(INDI::Property &property);
+
     public:
         /**
          * \brief Set connection switch status in the client.
@@ -296,7 +304,7 @@ class DefaultDevice : public BaseDevice
         /**
          * @return getInterface Return the interface declared by the driver.
          */
-        virtual uint16_t getDriverInterface() override;
+        uint16_t getDriverInterface() const;
 
         /**
          * @brief setInterface Set driver interface. By default the driver interface is set to GENERAL_DEVICE.
@@ -307,6 +315,13 @@ class DefaultDevice : public BaseDevice
          */
         void setDriverInterface(uint16_t value);
 
+    public:
+        /** @brief Add a device to the watch list.
+         *
+         *  A driver may select to receive notifications of a specific other device.
+         */
+        void watchDevice(const char *deviceName, const std::function<void (INDI::BaseDevice)> &callback);
+
     protected:
         /**
          * @brief setDynamicPropertiesBehavior controls handling of dynamic properties. Dyanmic properties
@@ -335,6 +350,15 @@ class DefaultDevice : public BaseDevice
          */
         virtual bool loadConfig(bool silent = false, const char *property = nullptr);
 
+        /**
+         * @brief Load property config from the configuration file. If the property configuration is successfully parsed, the corresponding ISNewXXX
+         * is called with the values parsed from the config file.
+         * @param property Property to load configuration for.
+         * @return True if successful, false otherwise.
+         * @note This is a convenience function that calls loadConfig(true, property->getName())
+         */
+        bool loadConfig(INDI::Property &property);
+
         /**
          * \brief Save the current properties in a configuration file
          * \param silent if true, don't report any error or notification messages.
@@ -344,6 +368,14 @@ class DefaultDevice : public BaseDevice
          */
         virtual bool saveConfig(bool silent = false, const char *property = nullptr);
 
+        /**
+         * @brief Save a property in the configuration file
+         * @param property Property to save in configuration file.
+         * @return True if successful, false otherwise.
+         * @note This is a convenience function that calls saveConfig(true, property->getName())
+         */
+        bool saveConfig(INDI::Property &property);
+
         /**
          * @brief purgeConfig Remove config file from disk.
          * @return True if successful, false otherwise.
@@ -534,7 +566,7 @@ class DefaultDevice : public BaseDevice
         friend class FocuserInterface;
 
     protected:
-        DefaultDevice(DefaultDevicePrivate &dd);
+        DefaultDevice(const std::shared_ptr<DefaultDevicePrivate> &dd);
 };
 
 }
