@@ -19,9 +19,11 @@
 #pragma once
 
 #include "indiapi.h"
+#include "indidriver.h"
 
 #include <sys/time.h>
 #include <stdint.h>
+#include <fitsio.h>
 
 namespace INDI
 {
@@ -48,6 +50,26 @@ class CCDChip
             CCD_BITSPERPIXEL
         } CCD_INFO_INDEX;
 
+        /**
+         * @brief openFITSFile Allocate memory buffer for internal FITS file structure and open
+         * @param FITS error code in case an error happens.
+         * an in-memory FITS file as a Shared BLOB.
+         * @return True if successful, false otherwise.
+         */
+        bool openFITSFile(uint32_t size, int &status);
+
+
+        /**
+         * @brief Finish any pending write to fits file.
+         * @return True if successful, false otherwise.
+         */
+        bool finishFITSFile(int &status);
+
+        /**
+         * @brief closeFITSFile Close the in-memory FITS File.
+         */
+        void closeFITSFile();
+
         /**
          * @brief getXRes Get the horizontal resolution in pixels of the CCD Chip.
          * @return the horizontal resolution of the CCD Chip.
@@ -391,6 +413,21 @@ class CCDChip
          */
         void binBayerFrame();
 
+        fitsfile **fitsFilePointer()
+        {
+            return &m_FITSFilePointer;
+        }
+
+        size_t * fitsMemorySizePointer()
+        {
+            return &m_FITSMemorySize;
+        }
+
+        void ** fitsMemoryBlockPointer()
+        {
+            return &m_FITSMemoryBlock;
+        }
+
     private:
         /////////////////////////////////////////////////////////////////////////////////////////
         /// Chip Variables
@@ -437,6 +474,9 @@ class CCDChip
         timeval StartExposureTime;
         // Image extension type (e.g. jpg)
         char ImageExtention[MAXINDIBLOBFMT];
+        void * m_FITSMemoryBlock {nullptr};
+        size_t m_FITSMemorySize {2880};
+        fitsfile * m_FITSFilePointer {nullptr};
 
         /////////////////////////////////////////////////////////////////////////////////////////
         /// Chip Properties
