@@ -62,9 +62,9 @@ SensorInterface::SensorInterface()
     RA              = -1000;
     Dec             = -1000;
     MPSAS           = -1000;
-    Lat             = -1000;
-    Lon             = -1000;
-    El              = -1000;
+    Latitude             = -1000;
+    Longitude             = -1000;
+    Elevation              = -1000;
     primaryAperture = primaryFocalLength - 1;
 
     Buffer     = static_cast<uint8_t *>(malloc(sizeof(uint8_t))); // Seed for realloc
@@ -89,25 +89,25 @@ bool SensorInterface::updateProperties()
     //IDLog("Sensor UpdateProperties isConnected returns %d %d\n",isConnected(),Connected);
     if (isConnected())
     {
-        defineNumber(&FramedIntegrationNP);
+        defineProperty(&FramedIntegrationNP);
 
         if (CanAbort())
-            defineSwitch(&AbortIntegrationSP);
+            defineProperty(&AbortIntegrationSP);
 
-        defineText(&FITSHeaderTP);
+        defineProperty(&FITSHeaderTP);
 
         if (HasCooler())
-            defineNumber(&TemperatureNP);
+            defineProperty(&TemperatureNP);
 
-        defineBLOB(&FitsBP);
+        defineProperty(&FitsBP);
 
-        defineSwitch(&TelescopeTypeSP);
+        defineProperty(&TelescopeTypeSP);
 
-        defineSwitch(&UploadSP);
+        defineProperty(&UploadSP);
 
         if (UploadSettingsT[UPLOAD_DIR].text == nullptr)
             IUSaveText(&UploadSettingsT[UPLOAD_DIR], getenv("HOME"));
-        defineText(&UploadSettingsTP);
+        defineProperty(&UploadSettingsTP);
     }
     else
     {
@@ -139,7 +139,7 @@ void SensorInterface::processProperties(const char *dev)
 {
     INDI::DefaultDevice::ISGetProperties(dev);
 
-    defineText(&ActiveDeviceTP);
+    defineProperty(&ActiveDeviceTP);
     loadConfig(true, "ACTIVE_DEVICES");
 
     if (HasStreaming())
@@ -159,10 +159,10 @@ bool SensorInterface::processSnoopDevice(XMLEle *root)
     }
     if (!IUSnoopNumber(root, &LocationNP))
     {
-        Lat = LocationNP.np[0].value;
-        Lon = LocationNP.np[1].value;
-        El = LocationNP.np[2].value;
-        //IDLog("Snooped Lat %4.2f  Lon %4.2f  El %4.2f\n", RA, Dec, El);
+        Latitude = LocationNP.np[0].value;
+        Longitude = LocationNP.np[1].value;
+        Elevation = LocationNP.np[2].value;
+        //IDLog("Snooped Latitude %4.2f  Longitude %4.2f  Elevation %4.2f\n", RA, Dec, Elevation);
     }
     if (!IUSnoopNumber(root, &ScopeParametersNP))
     {
@@ -318,12 +318,12 @@ bool SensorInterface::processSwitch(const char *dev, const char *name, ISState *
             else if (UploadS[1].s == ISS_ON)
             {
                 DEBUG(Logger::DBG_SESSION, "Upload settings set to local only.");
-                defineText(&FileNameTP);
+                defineProperty(&FileNameTP);
             }
             else
             {
                 DEBUG(Logger::DBG_SESSION, "Upload settings set to client and local.");
-                defineText(&FileNameTP);
+                defineProperty(&FileNameTP);
             }
             return true;
         }
@@ -457,8 +457,8 @@ bool SensorInterface::initProperties()
     IUFillNumberVector(&EqNP, EqN, 2, getDeviceName(), "EQUATORIAL_EOD_COORD", "Eq. Coordinates", MAIN_CONTROL_TAB,
                        IP_RW, 60, IPS_IDLE);
 
-    IUFillNumber(&LocationN[0], "LAT", "Lat (dd:mm:ss)", "%010.6m", -90, 90, 0, 0.0);
-    IUFillNumber(&LocationN[1], "LONG", "Lon (dd:mm:ss)", "%010.6m", 0, 360, 0, 0.0);
+    IUFillNumber(&LocationN[0], "LAT", "Latitude (dd:mm:ss)", "%010.6m", -90, 90, 0, 0.0);
+    IUFillNumber(&LocationN[1], "LONG", "Longitude (dd:mm:ss)", "%010.6m", 0, 360, 0, 0.0);
     IUFillNumber(&LocationN[2], "ELEV", "Elevation (m)", "%g", -200, 10000, 0, 0);
     IUFillNumberVector(&LocationNP, LocationN, 3, getDeviceName(), "GEOGRAPHIC_COORD", "Location", MAIN_CONTROL_TAB,
                        IP_RO, 60, IPS_IDLE);
@@ -512,22 +512,22 @@ void SensorInterface::SetCapability(uint32_t cap)
 void SensorInterface::setMinMaxStep(const char *property, const char *element, double min, double max, double step,
                                     bool sendToClient)
 {
-    INumberVectorProperty *vp = nullptr;
+    INumberVectorProperty *nvp = nullptr;
 
     if (!strcmp(property, FramedIntegrationNP.name))
+        nvp = &FramedIntegrationNP;
+    else
+        return;
+
+    INumber *np = IUFindNumber(nvp, element);
+    if (np)
     {
-        vp = &FramedIntegrationNP;
+        np->min  = min;
+        np->max  = max;
+        np->step = step;
 
-        INumber *np = IUFindNumber(vp, element);
-        if (np)
-        {
-            np->min  = min;
-            np->max  = max;
-            np->step = step;
-
-            if (sendToClient)
-                IUUpdateMinMax(vp);
-        }
+        if (sendToClient)
+            IUUpdateMinMax(nvp);
     }
 }
 
@@ -539,8 +539,11 @@ void SensorInterface::setBufferSize(int nbuf, bool allocMem)
     BufferSize = nbuf;
 
     // Reset size
-    if (HasStreaming())
-        Streamer->setSize(BufferSize * 8 / getBPS());
+    if(HasStreaming())
+    {
+        Streamer->setPixelFormat(INDI_MONO, getBPS());
+        Streamer->setSize(getBufferSize() * 8 / abs(getBPS()), 1);
+    }
 
     // DSP
     if (HasDSP())
@@ -577,15 +580,13 @@ void SensorInterface::setIntegrationTime(double duration)
 
 const char *SensorInterface::getIntegrationStartTime()
 {
-    static char ts[32];
-
-    char iso8601[32];
+    static char iso8601[32];
     struct tm *tp;
     time_t t = (time_t)startIntegrationTime;
 
     tp = gmtime(&t);
     strftime(iso8601, sizeof(iso8601), "%Y-%m-%dT%H:%M:%S", tp);
-    return (ts);
+    return iso8601;
 }
 
 void SensorInterface::setIntegrationFailed()
@@ -607,6 +608,8 @@ void SensorInterface::setNAxis(int value)
 void SensorInterface::setIntegrationFileExtension(const char *ext)
 {
     strncpy(integrationExtention, ext, MAXINDIBLOBFMT);
+    if(HasDSP())
+        DSP->setCaptureFileExtension(ext);
 }
 
 
@@ -671,6 +674,9 @@ void SensorInterface::addFITSKeywords(fitsfile *fptr, uint8_t* buf, int len)
     }
 #endif
 
+    if (primaryAperture != -1)
+        fits_update_key_s(fptr, TDOUBLE, "APTDIA", &primaryAperture, "Diameter (mm)", &status);
+
     if (primaryFocalLength != -1)
         fits_update_key_s(fptr, TDOUBLE, "FOCALLEN", &primaryFocalLength, "Focal Length (mm)", &status);
 
@@ -679,31 +685,30 @@ void SensorInterface::addFITSKeywords(fitsfile *fptr, uint8_t* buf, int len)
         fits_update_key_s(fptr, TDOUBLE, "MPSAS", &MPSAS, "Sky Quality (mag per arcsec^2)", &status);
     }
 
-    if (Lat != -1000 && Lon != -1000 && El != -1000)
+    if (Latitude != -1000 && Longitude != -1000 && Elevation != -1000)
     {
         char lat_str[MAXINDIFORMAT];
         char lon_str[MAXINDIFORMAT];
         char el_str[MAXINDIFORMAT];
-        fs_sexa(lat_str, Lat, 2, 360000);
-        fs_sexa(lat_str, Lon, 2, 360000);
-        snprintf(el_str, MAXINDIFORMAT, "%lf", El);
-        fits_update_key_s(fptr, TSTRING, "LATITUDE", lat_str, "Location Latitude", &status);
-        fits_update_key_s(fptr, TSTRING, "LONGITUDE", lon_str, "Location Longitude", &status);
-        fits_update_key_s(fptr, TSTRING, "ELEVATION", el_str, "Location Elevation", &status);
+        fs_sexa(lat_str, Latitude, 2, 360000);
+        fs_sexa(lon_str, Longitude, 2, 360000);
+        snprintf(el_str, MAXINDIFORMAT, "%lf", Elevation);
+        fits_update_key_s(fptr, TSTRING, "SITELAT", lat_str, "Location Latitude", &status);
+        fits_update_key_s(fptr, TSTRING, "SITELONG", lon_str, "Location Longitude", &status);
+        fits_update_key_s(fptr, TSTRING, "SITEELEV", el_str, "Location Elevation", &status);
     }
     if (RA != -1000 && Dec != -1000)
     {
-        ln_equ_posn epochPos { 0, 0 }, J2000Pos { 0, 0 };
-        epochPos.ra  = RA * 15.0;
-        epochPos.dec = Dec;
+        INDI::IEquatorialCoordinates epochPos { 0, 0 }, J2000Pos { 0, 0 };
+        epochPos.rightascension  = RA;
+        epochPos.declination = Dec;
 
         // Convert from JNow to J2000
         //TODO use exp_start instead of julian from system
-        //ln_get_equ_prec2(&epochPos, ln_get_julian_from_sys(), JD2000, &J2000Pos);
-        LibAstro::ObservedToJ2000(&epochPos, ln_get_julian_from_sys(), &J2000Pos);
+        INDI::ObservedToJ2000(&epochPos, ln_get_julian_from_sys(), &J2000Pos);
 
-        double raJ2000  = J2000Pos.ra / 15.0;
-        double decJ2000 = J2000Pos.dec;
+        double raJ2000  = J2000Pos.rightascension;
+        double decJ2000 = J2000Pos.declination;
         char ra_str[32], de_str[32];
 
         fs_sexa(ra_str, raJ2000, 2, 360000);
@@ -732,7 +737,7 @@ void SensorInterface::addFITSKeywords(fitsfile *fptr, uint8_t* buf, int len)
         fits_update_key_s(fptr, TINT, "EQUINOX", &epoch, "Equinox", &status);
     }
 
-    fits_update_key_s(fptr, TSTRING, "TIMESTAMP", timestamp, "Timestamp of start of integration", &status);
+    fits_update_key_s(fptr, TSTRING, "EPOCH", timestamp, "Unix Epoch of start of integration", &status);
 
     fits_update_key_s(fptr, TSTRING, "DATE-OBS", exp_start, "UTC start date of observation", &status);
 
@@ -869,7 +874,7 @@ void* SensorInterface::sendFITS(uint8_t *buf, int len)
 bool SensorInterface::IntegrationComplete()
 {
     // Reset POLLMS to default value
-    POLLMS = getPollingPeriod();
+    setCurrentPollingPeriod(getPollingPeriod());
 
     if(HasDSP())
     {
